{
  "type": "record",
  "name": "MetadataChangeEvent",
  "namespace": "com.linkedin.pegasus2avro.mxe",
  "fields": [
    {
      "type": [
        "null",
        {
          "type": "record",
          "name": "KafkaAuditHeader",
          "namespace": "com.linkedin.events",
          "fields": [
            {
              "compliance": [
                {
                  "policy": "EVENT_TIME"
                }
              ],
              "type": "long",
              "name": "time",
              "doc": "The time at which the event was emitted into kafka."
            },
            {
              "compliance": "NONE",
              "type": "string",
              "name": "server",
              "doc": "The fully qualified name of the host from which the event is being emitted."
            },
            {
              "compliance": "NONE",
              "type": [
                "null",
                "string"
              ],
              "name": "instance",
              "default": null,
              "doc": "The instance on the server from which the event is being emitted. e.g. i001"
            },
            {
              "compliance": "NONE",
              "type": "string",
              "name": "appName",
              "doc": "The name of the application from which the event is being emitted. see go/appname"
            },
            {
              "compliance": "NONE",
              "type": {
                "type": "fixed",
                "name": "UUID",
                "namespace": "com.linkedin.events",
                "size": 16
              },
              "name": "messageId",
              "doc": "A unique identifier for the message"
            },
            {
              "compliance": "NONE",
              "type": [
                "null",
                "int"
              ],
              "name": "auditVersion",
              "default": null,
              "doc": "The version that is being used for auditing. In version 0, the audit trail buckets events into 10 minute audit windows based on the EventHeader timestamp. In version 1, the audit trail buckets events as follows: if the schema has an outer KafkaAuditHeader, use the outer audit header timestamp for bucketing; else if the EventHeader has an inner KafkaAuditHeader use that inner audit header's timestamp for bucketing"
            },
            {
              "compliance": "NONE",
              "type": [
                "null",
                "string"
              ],
              "name": "fabricUrn",
              "default": null,
              "doc": "The fabricUrn of the host from which the event is being emitted. Fabric Urn in the format of urn:li:fabric:{fabric_name}. See go/fabric."
            },
            {
              "compliance": "NONE",
              "type": [
                "null",
                "string"
              ],
              "name": "clusterConnectionString",
              "default": null,
              "doc": "This is a String that the client uses to establish some kind of connection with the Kafka cluster. The exact format of it depends on specific versions of clients and brokers. This information could potentially identify the fabric and cluster with which the client is producing to or consuming from."
            }
          ],
          "doc": "This header records information about the context of an event as it is emitted into kafka and is intended to be used by the kafka audit application.  For more information see go/kafkaauditheader"
        }
      ],
      "name": "auditHeader",
      "default": null,
      "doc": "Kafka audit header. See go/kafkaauditheader for more info."
    },
    {
      "type": [
        {
          "type": "record",
          "Entity": {
            "keyAspect": "chartKey",
            "name": "chart"
          },
          "name": "ChartSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.ChartUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "ChartUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "chartKey"
                    },
                    "name": "ChartKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 4.0,
                          "fieldName": "tool",
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "dashboardTool",
                        "doc": "The name of the dashboard tool such as looker, redash etc."
                      },
                      {
                        "type": "string",
                        "name": "chartId",
                        "doc": "Unique id for the chart. This id should be globally unique for a dashboarding tool even when there are multiple deployments of it. As an example, chart URL could be used here for Looker such as 'looker.linkedin.com/looks/1234'"
                      }
                    ],
                    "doc": "Key for a Chart"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "chartInfo"
                    },
                    "name": "ChartInfo",
                    "namespace": "com.linkedin.pegasus2avro.chart",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "title",
                        "doc": "Title of the chart"
                      },
                      {
                        "Searchable": {},
                        "type": "string",
                        "name": "description",
                        "doc": "Detailed description about the chart"
                      },
                      {
                        "type": {
                          "type": "record",
                          "name": "ChangeAuditStamps",
                          "namespace": "com.linkedin.pegasus2avro.common",
                          "fields": [
                            {
                              "type": {
                                "type": "record",
                                "name": "AuditStamp",
                                "namespace": "com.linkedin.pegasus2avro.common",
                                "fields": [
                                  {
                                    "type": "long",
                                    "name": "time",
                                    "doc": "When did the resource/association/sub-resource move into the specific lifecycle stage represented by this AuditEvent."
                                  },
                                  {
                                    "java": {
                                      "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                    },
                                    "type": "string",
                                    "name": "actor",
                                    "doc": "The entity (e.g. a member URN) which will be credited for moving the resource/association/sub-resource into the specific lifecycle stage. It is also the one used to authorize the change.",
                                    "Urn": "Urn"
                                  },
                                  {
                                    "java": {
                                      "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                    },
                                    "type": [
                                      "null",
                                      "string"
                                    ],
                                    "name": "impersonator",
                                    "default": null,
                                    "doc": "The entity (e.g. a service URN) which performs the change on behalf of the Actor and must be authorized to act as the Actor.",
                                    "Urn": "Urn"
                                  },
                                  {
                                    "type": [
                                      "null",
                                      "string"
                                    ],
                                    "name": "message",
                                    "default": null,
                                    "doc": "Additional context around how DataHub was informed of the particular change. For example: was the change created by an automated process, or manually."
                                  }
                                ],
                                "doc": "Data captured on a resource/association/sub-resource level giving insight into when that resource/association/sub-resource moved into a particular lifecycle stage, and who acted to move it into that specific lifecycle stage."
                              },
                              "name": "created",
                              "default": {
                                "actor": "urn:li:corpuser:unknown",
                                "impersonator": null,
                                "time": 0,
                                "message": null
                              },
                              "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                            },
                            {
                              "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                              "name": "lastModified",
                              "default": {
                                "actor": "urn:li:corpuser:unknown",
                                "impersonator": null,
                                "time": 0,
                                "message": null
                              },
                              "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                            },
                            {
                              "type": [
                                "null",
                                "com.linkedin.pegasus2avro.common.AuditStamp"
                              ],
                              "name": "deleted",
                              "default": null,
                              "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                            }
                          ],
                          "doc": "Data captured on a resource/association/sub-resource level giving insight into when that resource/association/sub-resource moved into various lifecycle stages, and who acted to move it into those lifecycle stages. The recommended best practice is to include this record in your record schema, and annotate its fields as @readOnly in your resource. See https://github.com/linkedin/rest.li/wiki/Validation-in-Rest.li#restli-validation-annotations"
                        },
                        "name": "lastModified",
                        "doc": "Captures information about who created/last modified/deleted this chart and when"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "chartUrl",
                        "default": null,
                        "doc": "URL for the chart. This could be used as an external link on DataHub to allow users access/view the chart"
                      },
                      {
                        "Relationship": {
                          "/*/string": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes"
                          }
                        },
                        "deprecated": true,
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": [
                              "string"
                            ]
                          }
                        ],
                        "name": "inputs",
                        "default": null,
                        "doc": "Data sources for the chart\nDeprecated! Use inputEdges instead."
                      },
                      {
                        "Relationship": {
                          "/*/destinationUrn": {
                            "createdActor": "inputEdges/*/created/actor",
                            "createdOn": "inputEdges/*/created/time",
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes",
                            "properties": "inputEdges/*/properties",
                            "updatedActor": "inputEdges/*/lastModified/actor",
                            "updatedOn": "inputEdges/*/lastModified/time"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": {
                              "type": "record",
                              "name": "Edge",
                              "namespace": "com.linkedin.pegasus2avro.common",
                              "fields": [
                                {
                                  "java": {
                                    "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                  },
                                  "type": [
                                    "null",
                                    "string"
                                  ],
                                  "name": "sourceUrn",
                                  "default": null,
                                  "doc": "Urn of the source of this relationship edge.\nIf not specified, assumed to be the entity that this aspect belongs to.",
                                  "Urn": "Urn"
                                },
                                {
                                  "java": {
                                    "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                  },
                                  "type": "string",
                                  "name": "destinationUrn",
                                  "doc": "Urn of the destination of this relationship edge.",
                                  "Urn": "Urn"
                                },
                                {
                                  "type": [
                                    "null",
                                    "com.linkedin.pegasus2avro.common.AuditStamp"
                                  ],
                                  "name": "created",
                                  "default": null,
                                  "doc": "Audit stamp containing who created this relationship edge and when"
                                },
                                {
                                  "type": [
                                    "null",
                                    "com.linkedin.pegasus2avro.common.AuditStamp"
                                  ],
                                  "name": "lastModified",
                                  "default": null,
                                  "doc": "Audit stamp containing who last modified this relationship edge and when"
                                },
                                {
                                  "type": [
                                    "null",
                                    {
                                      "type": "map",
                                      "values": "string"
                                    }
                                  ],
                                  "name": "properties",
                                  "default": null,
                                  "doc": "A generic properties bag that allows us to store specific information on this graph edge."
                                }
                              ],
                              "doc": "A common structure to represent all edges to entities when used inside aspects as collections\nThis ensures that all edges have common structure around audit-stamps and will support PATCH, time-travel automatically."
                            }
                          }
                        ],
                        "name": "inputEdges",
                        "default": null,
                        "doc": "Data sources for the chart"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "KEYWORD",
                          "filterNameOverride": "Chart Type"
                        },
                        "type": [
                          "null",
                          {
                            "type": "enum",
                            "symbolDocs": {
                              "BAR": "Chart showing a Bar chart",
                              "PIE": "Chart showing a Pie chart",
                              "SCATTER": "Chart showing a Scatter plot",
                              "TABLE": "Chart showing a table",
                              "TEXT": "Chart showing Markdown formatted text"
                            },
                            "name": "ChartType",
                            "namespace": "com.linkedin.pegasus2avro.chart",
                            "symbols": [
                              "BAR",
                              "PIE",
                              "SCATTER",
                              "TABLE",
                              "TEXT",
                              "LINE",
                              "AREA",
                              "HISTOGRAM",
                              "BOX_PLOT",
                              "WORD_CLOUD",
                              "COHORT"
                            ],
                            "doc": "The various types of charts"
                          }
                        ],
                        "name": "type",
                        "default": null,
                        "doc": "Type of the chart"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "KEYWORD",
                          "filterNameOverride": "Access Level"
                        },
                        "type": [
                          "null",
                          {
                            "type": "enum",
                            "symbolDocs": {
                              "PRIVATE": "Private availability to certain set of users",
                              "PUBLIC": "Publicly available access level"
                            },
                            "name": "AccessLevel",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "symbols": [
                              "PUBLIC",
                              "PRIVATE"
                            ],
                            "doc": "The various access levels"
                          }
                        ],
                        "name": "access",
                        "default": null,
                        "doc": "Access level for the chart"
                      },
                      {
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "lastRefreshed",
                        "default": null,
                        "doc": "The time when this chart last refreshed"
                      }
                    ],
                    "doc": "Information about a chart"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "chartQuery"
                    },
                    "name": "ChartQuery",
                    "namespace": "com.linkedin.pegasus2avro.chart",
                    "fields": [
                      {
                        "type": "string",
                        "name": "rawQuery",
                        "doc": "Raw query to build a chart from input datasets"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldName": "queryType",
                          "fieldType": "KEYWORD",
                          "filterNameOverride": "Query Type"
                        },
                        "type": {
                          "type": "enum",
                          "symbolDocs": {
                            "LOOKML": "LookML queries",
                            "SQL": "SQL type queries"
                          },
                          "name": "ChartQueryType",
                          "namespace": "com.linkedin.pegasus2avro.chart",
                          "symbols": [
                            "LOOKML",
                            "SQL"
                          ]
                        },
                        "name": "type",
                        "doc": "Chart query type"
                      }
                    ],
                    "doc": "Information for chart query which is used for getting data of the chart"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "editableChartProperties"
                    },
                    "name": "EditableChartProperties",
                    "namespace": "com.linkedin.pegasus2avro.chart",
                    "fields": [
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "created",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "deleted",
                        "default": null,
                        "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                      },
                      {
                        "Searchable": {
                          "fieldName": "editedDescription",
                          "fieldType": "TEXT"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Edited documentation of the chart "
                      }
                    ],
                    "doc": "Stores editable changes made to properties. This separates changes made from\ningestion pipelines and edits in the UI to avoid accidental overwrites of user-provided data by ingestion pipelines"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "ownership"
                    },
                    "name": "Ownership",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "Owner",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "fields": [
                              {
                                "Relationship": {
                                  "entityTypes": [
                                    "corpuser",
                                    "corpGroup"
                                  ],
                                  "name": "OwnedBy"
                                },
                                "Searchable": {
                                  "addToFilters": true,
                                  "fieldName": "owners",
                                  "fieldType": "URN",
                                  "filterNameOverride": "Owned By",
                                  "hasValuesFieldName": "hasOwners",
                                  "queryByDefault": false
                                },
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                },
                                "type": "string",
                                "name": "owner",
                                "doc": "Owner URN, e.g. urn:li:corpuser:ldap, urn:li:corpGroup:group_name, and urn:li:multiProduct:mp_name\n(Caveat: only corpuser is currently supported in the frontend.)",
                                "Urn": "Urn",
                                "entityTypes": [
                                  "corpuser",
                                  "corpGroup"
                                ]
                              },
                              {
                                "deprecated": true,
                                "type": {
                                  "type": "enum",
                                  "symbolDocs": {
                                    "BUSINESS_OWNER": "A person or group who is responsible for logical, or business related, aspects of the asset.",
                                    "CONSUMER": "A person, group, or service that consumes the data\nDeprecated! Use TECHNICAL_OWNER or BUSINESS_OWNER instead.",
                                    "CUSTOM": "Set when ownership type is unknown or a when new one is specified as an ownership type entity for which we have no\nenum value for. This is used for backwards compatibility",
                                    "DATAOWNER": "A person or group that is owning the data\nDeprecated! Use TECHNICAL_OWNER instead.",
                                    "DATA_STEWARD": "A steward, expert, or delegate responsible for the asset.",
                                    "DELEGATE": "A person or a group that overseas the operation, e.g. a DBA or SRE.\nDeprecated! Use TECHNICAL_OWNER instead.",
                                    "DEVELOPER": "A person or group that is in charge of developing the code\nDeprecated! Use TECHNICAL_OWNER instead.",
                                    "NONE": "No specific type associated to the owner.",
                                    "PRODUCER": "A person, group, or service that produces/generates the data\nDeprecated! Use TECHNICAL_OWNER instead.",
                                    "STAKEHOLDER": "A person or a group that has direct business interest\nDeprecated! Use TECHNICAL_OWNER, BUSINESS_OWNER, or STEWARD instead.",
                                    "TECHNICAL_OWNER": "person or group who is responsible for technical aspects of the asset."
                                  },
                                  "deprecatedSymbols": {
                                    "CONSUMER": true,
                                    "DATAOWNER": true,
                                    "DELEGATE": true,
                                    "DEVELOPER": true,
                                    "PRODUCER": true,
                                    "STAKEHOLDER": true
                                  },
                                  "name": "OwnershipType",
                                  "namespace": "com.linkedin.pegasus2avro.common",
                                  "symbols": [
                                    "CUSTOM",
                                    "TECHNICAL_OWNER",
                                    "BUSINESS_OWNER",
                                    "DATA_STEWARD",
                                    "NONE",
                                    "DEVELOPER",
                                    "DATAOWNER",
                                    "DELEGATE",
                                    "PRODUCER",
                                    "CONSUMER",
                                    "STAKEHOLDER"
                                  ],
                                  "doc": "Asset owner types"
                                },
                                "name": "type",
                                "doc": "The type of the ownership"
                              },
                              {
                                "Relationship": {
                                  "entityTypes": [
                                    "ownershipType"
                                  ],
                                  "name": "ownershipType"
                                },
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "typeUrn",
                                "default": null,
                                "doc": "The type of the ownership\nUrn of type O",
                                "Urn": "Urn",
                                "entityTypes": [
                                  "ownershipType"
                                ]
                              },
                              {
                                "type": [
                                  "null",
                                  {
                                    "type": "record",
                                    "name": "OwnershipSource",
                                    "namespace": "com.linkedin.pegasus2avro.common",
                                    "fields": [
                                      {
                                        "type": {
                                          "type": "enum",
                                          "symbolDocs": {
                                            "AUDIT": "Auditing system or audit logs",
                                            "DATABASE": "Database, e.g. GRANTS table",
                                            "FILE_SYSTEM": "File system, e.g. file/directory owner",
                                            "ISSUE_TRACKING_SYSTEM": "Issue tracking system, e.g. Jira",
                                            "MANUAL": "Manually provided by a user",
                                            "OTHER": "Other sources",
                                            "SERVICE": "Other ownership-like service, e.g. Nuage, ACL service etc",
                                            "SOURCE_CONTROL": "SCM system, e.g. GIT, SVN"
                                          },
                                          "name": "OwnershipSourceType",
                                          "namespace": "com.linkedin.pegasus2avro.common",
                                          "symbols": [
                                            "AUDIT",
                                            "DATABASE",
                                            "FILE_SYSTEM",
                                            "ISSUE_TRACKING_SYSTEM",
                                            "MANUAL",
                                            "SERVICE",
                                            "SOURCE_CONTROL",
                                            "OTHER"
                                          ]
                                        },
                                        "name": "type",
                                        "doc": "The type of the source"
                                      },
                                      {
                                        "type": [
                                          "null",
                                          "string"
                                        ],
                                        "name": "url",
                                        "default": null,
                                        "doc": "A reference URL for the source"
                                      }
                                    ],
                                    "doc": "Source/provider of the ownership information"
                                  }
                                ],
                                "name": "source",
                                "default": null,
                                "doc": "Source information for the ownership"
                              }
                            ],
                            "doc": "Ownership information"
                          }
                        },
                        "name": "owners",
                        "doc": "List of owners of the entity."
                      },
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "MAP_ARRAY",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          {
                            "type": "map",
                            "values": {
                              "type": "array",
                              "items": "string"
                            }
                          },
                          "null"
                        ],
                        "name": "ownerTypes",
                        "default": {},
                        "doc": "Ownership type to Owners map, populated via mutation hook."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "Audit stamp containing who last modified the record and when. A value of 0 in the time field indicates missing data."
                      }
                    ],
                    "doc": "Ownership information of an entity."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "status"
                    },
                    "name": "Status",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "BOOLEAN"
                        },
                        "type": "boolean",
                        "name": "removed",
                        "default": false,
                        "doc": "Whether the entity has been removed (soft-deleted)."
                      }
                    ],
                    "doc": "The lifecycle status metadata of an entity, e.g. dataset, metric, feature, etc.\nThis aspect is used to represent soft deletes conventionally."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "globalTags"
                    },
                    "name": "GlobalTags",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "Relationship": {
                          "/*/tag": {
                            "entityTypes": [
                              "tag"
                            ],
                            "name": "TaggedWith"
                          }
                        },
                        "Searchable": {
                          "/*/tag": {
                            "addToFilters": true,
                            "boostScore": 0.5,
                            "fieldName": "tags",
                            "fieldType": "URN",
                            "filterNameOverride": "Tag",
                            "hasValuesFieldName": "hasTags",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "TagAssociation",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "fields": [
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.TagUrn"
                                },
                                "type": "string",
                                "name": "tag",
                                "doc": "Urn of the applied tag",
                                "Urn": "TagUrn"
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "context",
                                "default": null,
                                "doc": "Additional context about the association"
                              },
                              {
                                "Searchable": {
                                  "/actor": {
                                    "fieldName": "tagAttributionActors",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/source": {
                                    "fieldName": "tagAttributionSources",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/time": {
                                    "fieldName": "tagAttributionDates",
                                    "fieldType": "DATETIME",
                                    "queryByDefault": false
                                  }
                                },
                                "type": [
                                  "null",
                                  {
                                    "type": "record",
                                    "name": "MetadataAttribution",
                                    "namespace": "com.linkedin.pegasus2avro.common",
                                    "fields": [
                                      {
                                        "type": "long",
                                        "name": "time",
                                        "doc": "When this metadata was updated."
                                      },
                                      {
                                        "java": {
                                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                        },
                                        "type": "string",
                                        "name": "actor",
                                        "doc": "The entity (e.g. a member URN) responsible for applying the assocated metadata. This can\neither be a user (in case of UI edits) or the datahub system for automation.",
                                        "Urn": "Urn"
                                      },
                                      {
                                        "java": {
                                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                        },
                                        "type": [
                                          "null",
                                          "string"
                                        ],
                                        "name": "source",
                                        "default": null,
                                        "doc": "The DataHub source responsible for applying the associated metadata. This will only be filled out\nwhen a DataHub source is responsible. This includes the specific metadata test urn, the automation urn.",
                                        "Urn": "Urn"
                                      },
                                      {
                                        "type": {
                                          "type": "map",
                                          "values": "string"
                                        },
                                        "name": "sourceDetail",
                                        "default": {},
                                        "doc": "The details associated with why this metadata was applied. For example, this could include\nthe actual regex rule, sql statement, ingestion pipeline ID, etc."
                                      }
                                    ],
                                    "doc": "Information about who, why, and how this metadata was applied"
                                  }
                                ],
                                "name": "attribution",
                                "default": null,
                                "doc": "Information about who, why, and how this metadata was applied"
                              }
                            ],
                            "doc": "Properties of an applied tag. For now, just an Urn. In the future we can extend this with other properties, e.g.\npropagation parameters."
                          }
                        },
                        "name": "tags",
                        "doc": "Tags associated with a given entity"
                      }
                    ],
                    "doc": "Tag aspect used for applying tags to an entity"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "browsePaths"
                    },
                    "name": "BrowsePaths",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldName": "browsePaths",
                            "fieldType": "BROWSE_PATH"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "paths",
                        "doc": "A list of valid browse paths for the entity.\n\nBrowse paths are expected to be forward slash-separated strings. For example: 'prod/snowflake/datasetName'"
                      }
                    ],
                    "doc": "Shared aspect containing Browse Paths to be indexed for an entity."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "glossaryTerms"
                    },
                    "name": "GlossaryTerms",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "GlossaryTermAssociation",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "fields": [
                              {
                                "Relationship": {
                                  "entityTypes": [
                                    "glossaryTerm"
                                  ],
                                  "name": "TermedWith"
                                },
                                "Searchable": {
                                  "addToFilters": true,
                                  "fieldName": "glossaryTerms",
                                  "fieldType": "URN",
                                  "filterNameOverride": "Glossary Term",
                                  "hasValuesFieldName": "hasGlossaryTerms",
                                  "includeSystemModifiedAt": true,
                                  "systemModifiedAtFieldName": "termsModifiedAt"
                                },
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.GlossaryTermUrn"
                                },
                                "type": "string",
                                "name": "urn",
                                "doc": "Urn of the applied glossary term",
                                "Urn": "GlossaryTermUrn",
                                "entityTypes": [
                                  "glossaryTerm"
                                ]
                              },
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "actor",
                                "default": null,
                                "doc": "The user URN which will be credited for adding associating this term to the entity",
                                "Urn": "Urn"
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "context",
                                "default": null,
                                "doc": "Additional context about the association"
                              },
                              {
                                "Searchable": {
                                  "/actor": {
                                    "fieldName": "termAttributionActors",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/source": {
                                    "fieldName": "termAttributionSources",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/time": {
                                    "fieldName": "termAttributionDates",
                                    "fieldType": "DATETIME",
                                    "queryByDefault": false
                                  }
                                },
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.MetadataAttribution"
                                ],
                                "name": "attribution",
                                "default": null,
                                "doc": "Information about who, why, and how this metadata was applied"
                              }
                            ],
                            "doc": "Properties of an applied glossary term."
                          }
                        },
                        "name": "terms",
                        "doc": "The related business terms"
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "auditStamp",
                        "doc": "Audit stamp containing who reported the related business term"
                      }
                    ],
                    "doc": "Related business terms information"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "institutionalMemory"
                    },
                    "name": "InstitutionalMemory",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "InstitutionalMemoryMetadata",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "fields": [
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.url.Url",
                                  "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                                },
                                "type": "string",
                                "name": "url",
                                "doc": "Link to an engineering design document or a wiki page."
                              },
                              {
                                "type": "string",
                                "name": "description",
                                "doc": "Description of the link."
                              },
                              {
                                "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                                "name": "createStamp",
                                "doc": "Audit stamp associated with creation of this record"
                              }
                            ],
                            "doc": "Metadata corresponding to a record of institutional memory."
                          }
                        },
                        "name": "elements",
                        "doc": "List of records that represent institutional memory of an entity. Each record consists of a link, description, creator and timestamps associated with that record."
                      }
                    ],
                    "doc": "Institutional memory of an entity. This is a way to link to relevant documentation and provide description of the documentation. Institutional or tribal knowledge is very important for users to leverage the entity."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataPlatformInstance"
                    },
                    "name": "DataPlatformInstance",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "URN",
                          "filterNameOverride": "Platform"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "platform",
                        "doc": "Data Platform",
                        "Urn": "Urn"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldName": "platformInstance",
                          "fieldType": "URN",
                          "filterNameOverride": "Platform Instance"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "instance",
                        "default": null,
                        "doc": "Instance of the data platform (e.g. db instance)",
                        "Urn": "Urn"
                      }
                    ],
                    "doc": "The specific instance of the data platform that this entity belongs to"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "browsePathsV2"
                    },
                    "name": "BrowsePathsV2",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "Searchable": {
                          "/*/id": {
                            "fieldName": "browsePathV2",
                            "fieldType": "BROWSE_PATH_V2"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "BrowsePathEntry",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "fields": [
                              {
                                "type": "string",
                                "name": "id",
                                "doc": "The ID of the browse path entry. This is what gets stored in the index.\nIf there's an urn associated with this entry, id and urn will be the same"
                              },
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "urn",
                                "default": null,
                                "doc": "Optional urn pointing to some entity in DataHub",
                                "Urn": "Urn"
                              }
                            ],
                            "doc": "Represents a single level in an entity's browsePathV2"
                          }
                        },
                        "name": "path",
                        "doc": "A valid browse path for the entity. This field is provided by DataHub by default.\nThis aspect is a newer version of browsePaths where we can encode more information in the path.\nThis path is also based on containers for a given entity if it has containers.\n\nThis is stored in elasticsearch as unit-separator delimited strings and only includes platform specific folders or containers.\nThese paths should not include high level info captured elsewhere ie. Platform and Environment."
                      }
                    ],
                    "doc": "Shared aspect containing a Browse Path to be indexed for an entity."
                  }
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the chart. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific Chart entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "corpGroupKey",
            "name": "corpGroup"
          },
          "name": "CorpGroupSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.CorpGroupUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "CorpGroupUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "corpGroupKey"
                    },
                    "name": "CorpGroupKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM",
                          "queryByDefault": true
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "The URL-encoded name of the AD/LDAP group. Serves as a globally unique identifier within DataHub."
                      }
                    ],
                    "doc": "Key for a CorpGroup"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "EntityUrns": [
                        "com.linkedin.pegasus2avro.common.CorpGroupUrn"
                      ],
                      "name": "corpGroupInfo"
                    },
                    "name": "CorpGroupInfo",
                    "namespace": "com.linkedin.pegasus2avro.identity",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "TEXT_PARTIAL",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "displayName",
                        "default": null,
                        "doc": "The name of the group."
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "email",
                        "default": null,
                        "doc": "email of this group"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "corpuser"
                            ],
                            "name": "OwnedBy"
                          }
                        },
                        "deprecated": true,
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "admins",
                        "doc": "owners of this group\nDeprecated! Replaced by Ownership aspect.",
                        "Urn": "CorpuserUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "corpuser"
                            ],
                            "name": "IsPartOf"
                          }
                        },
                        "deprecated": true,
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "members",
                        "doc": "List of ldap urn in this group.\nDeprecated! Replaced by GroupMembership aspect.",
                        "Urn": "CorpuserUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "corpGroup"
                            ],
                            "name": "IsPartOf"
                          }
                        },
                        "deprecated": true,
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "groups",
                        "doc": "List of groups in this group.\nDeprecated! This field is unused.",
                        "Urn": "CorpGroupUrn",
                        "urn_is_array": true
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "A description of the group."
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "slack",
                        "default": null,
                        "doc": "Slack channel for the group"
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "createdTime",
                            "fieldType": "DATETIME"
                          }
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "created",
                        "default": null,
                        "doc": "Created Audit stamp"
                      }
                    ],
                    "doc": "Information about a Corp Group ingested from a third party source"
                  },
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.Status"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the LdapUser. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific CorpGroup entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "corpUserKey",
            "name": "corpuser"
          },
          "name": "CorpUserSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.CorpuserUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "CorpuserUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "corpUserKey"
                    },
                    "name": "CorpUserKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 2.0,
                          "enableAutocomplete": true,
                          "fieldName": "ldap",
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "username",
                        "doc": "The name of the AD/LDAP user."
                      }
                    ],
                    "doc": "Key for a CorpUser"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "EntityUrns": [
                        "com.linkedin.pegasus2avro.common.CorpuserUrn"
                      ],
                      "name": "corpUserInfo"
                    },
                    "name": "CorpUserInfo",
                    "namespace": "com.linkedin.pegasus2avro.identity",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "BOOLEAN",
                          "weightsPerFieldValue": {
                            "true": 2.0
                          }
                        },
                        "type": "boolean",
                        "name": "active",
                        "doc": "Deprecated! Use CorpUserStatus instead. Whether the corpUser is active, ref: https://iwww.corp.linkedin.com/wiki/cf/display/GTSD/Accessing+Active+Directory+via+LDAP+tools"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "displayName",
                        "default": null,
                        "doc": "displayName of this user ,  e.g.  Hang Zhang(DataHQ)"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "email",
                        "default": null,
                        "doc": "email address of this user"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "title",
                        "default": null,
                        "doc": "title of this user"
                      },
                      {
                        "Relationship": {
                          "entityTypes": [
                            "corpuser"
                          ],
                          "name": "ReportsTo"
                        },
                        "Searchable": {
                          "fieldName": "managerLdap",
                          "fieldType": "URN",
                          "queryByDefault": false
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.CorpuserUrn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "managerUrn",
                        "default": null,
                        "doc": "direct manager of this user",
                        "Urn": "CorpuserUrn",
                        "entityTypes": [
                          "corpuser"
                        ]
                      },
                      {
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "departmentId",
                        "default": null,
                        "doc": "department id this user belong to"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "departmentName",
                        "default": null,
                        "doc": "department name this user belong to"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "firstName",
                        "default": null,
                        "doc": "first name of this user"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "lastName",
                        "default": null,
                        "doc": "last name of this user"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "fullName",
                        "default": null,
                        "doc": "Common name of this user, format is firstName + lastName (split by a whitespace)"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "countryCode",
                        "default": null,
                        "doc": "two uppercase letters country code. e.g.  US"
                      },
                      {
                        "Searchable": {
                          "fieldType": "BOOLEAN",
                          "queryByDefault": false
                        },
                        "type": [
                          "boolean",
                          "null"
                        ],
                        "name": "system",
                        "default": false,
                        "doc": "Whether the corpUser is a system user."
                      }
                    ],
                    "doc": "Linkedin corp user information"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "EntityUrns": [
                        "com.linkedin.pegasus2avro.common.CorpuserUrn"
                      ],
                      "name": "corpUserEditableInfo"
                    },
                    "name": "CorpUserEditableInfo",
                    "namespace": "com.linkedin.pegasus2avro.identity",
                    "fields": [
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "aboutMe",
                        "default": null,
                        "doc": "About me section of the user"
                      },
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "teams",
                        "default": [],
                        "doc": "Teams that the user belongs to e.g. Metadata"
                      },
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "skills",
                        "default": [],
                        "doc": "Skills that the user possesses e.g. Machine Learning"
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": "string",
                        "name": "pictureLink",
                        "default": "https://raw.githubusercontent.com/datahub-project/datahub/master/datahub-web-react/src/images/default_avatar.png",
                        "doc": "A URL which points to a picture which user wants to set as a profile photo"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "fieldType": "WORD_GRAM",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "displayName",
                        "default": null,
                        "doc": "DataHub-native display name"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "title",
                        "default": null,
                        "doc": "DataHub-native Title, e.g. 'Software Engineer'"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataPlatform"
                            ],
                            "name": "IsUserOf"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "platforms",
                        "default": null,
                        "doc": "The platforms that the user commonly works with",
                        "Urn": "Urn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "entityTypes": [
                            "dataHubPersona"
                          ],
                          "name": "IsPersona"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "persona",
                        "default": null,
                        "doc": "The user's persona type, based on their role",
                        "Urn": "Urn",
                        "entityTypes": [
                          "dataHubPersona"
                        ]
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "slack",
                        "default": null,
                        "doc": "Slack handle for the user"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "phone",
                        "default": null,
                        "doc": "Phone number to contact the user"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "email",
                        "default": null,
                        "doc": "Email address to contact the user"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "informationSources",
                        "default": null,
                        "doc": "Information sources that have been used to populate this CorpUserEditableInfo.\nThese include platform resources, such as Slack members or Looker users.\nThey can also refer to other semantic urns in the future.",
                        "Urn": "Urn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "Linkedin corp user information that can be edited from UI"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "corpUserStatus"
                    },
                    "name": "CorpUserStatus",
                    "namespace": "com.linkedin.pegasus2avro.identity",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "type": "string",
                        "name": "status",
                        "doc": "Status of the user, e.g. PROVISIONED / ACTIVE / SUSPENDED"
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "statusLastModifiedAt",
                            "fieldType": "COUNT"
                          }
                        },
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "doc": "Audit stamp containing who last modified the status and when."
                      }
                    ],
                    "doc": "The status of the user, e.g. provisioned, active, suspended, etc."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "groupMembership"
                    },
                    "name": "GroupMembership",
                    "namespace": "com.linkedin.pegasus2avro.identity",
                    "fields": [
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "corpGroup"
                            ],
                            "name": "IsMemberOfGroup"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "groups",
                        "Urn": "Urn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "Carries information about the CorpGroups a user is in."
                  },
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.Status"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the CorpUser. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific CorpUser entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "dashboardKey",
            "name": "dashboard"
          },
          "name": "DashboardSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.DashboardUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "DashboardUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dashboardKey"
                    },
                    "name": "DashboardKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 4.0,
                          "fieldName": "tool",
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "dashboardTool",
                        "doc": "The name of the dashboard tool such as looker, redash etc."
                      },
                      {
                        "type": "string",
                        "name": "dashboardId",
                        "doc": "Unique id for the dashboard. This id should be globally unique for a dashboarding tool even when there are multiple deployments of it. As an example, dashboard URL could be used here for Looker such as 'looker.linkedin.com/dashboards/1234'"
                      }
                    ],
                    "doc": "Key for a Dashboard"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dashboardInfo"
                    },
                    "name": "DashboardInfo",
                    "namespace": "com.linkedin.pegasus2avro.dashboard",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "title",
                        "doc": "Title of the dashboard"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": "string",
                        "name": "description",
                        "doc": "Detailed description about the dashboard"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "chart"
                            ],
                            "isLineage": true,
                            "name": "Contains"
                          }
                        },
                        "deprecated": true,
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "charts",
                        "default": [],
                        "doc": "Charts in a dashboard\nDeprecated! Use chartEdges instead.",
                        "Urn": "ChartUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*/destinationUrn": {
                            "createdActor": "chartEdges/*/created/actor",
                            "createdOn": "chartEdges/*/created/time",
                            "entityTypes": [
                              "chart"
                            ],
                            "isLineage": true,
                            "name": "Contains",
                            "properties": "chartEdges/*/properties",
                            "updatedActor": "chartEdges/*/lastModified/actor",
                            "updatedOn": "chartEdges/*/lastModified/time"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.common.Edge"
                          }
                        ],
                        "name": "chartEdges",
                        "default": null,
                        "doc": "Charts in a dashboard"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes"
                          }
                        },
                        "deprecated": true,
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "datasets",
                        "default": [],
                        "doc": "Datasets consumed by a dashboard\nDeprecated! Use datasetEdges instead.",
                        "Urn": "Urn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*/destinationUrn": {
                            "createdActor": "datasetEdges/*/created/actor",
                            "createdOn": "datasetEdges/*/created/time",
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes",
                            "properties": "datasetEdges/*/properties",
                            "updatedActor": "datasetEdges/*/lastModified/actor",
                            "updatedOn": "datasetEdges/*/lastModified/time"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.common.Edge"
                          }
                        ],
                        "name": "datasetEdges",
                        "default": null,
                        "doc": "Datasets consumed by a dashboard"
                      },
                      {
                        "Relationship": {
                          "/*/destinationUrn": {
                            "createdActor": "dashboards/*/created/actor",
                            "createdOn": "dashboards/*/created/time",
                            "entityTypes": [
                              "dashboard"
                            ],
                            "isLineage": true,
                            "name": "DashboardContainsDashboard",
                            "properties": "dashboards/*/properties",
                            "updatedActor": "dashboards/*/lastModified/actor",
                            "updatedOn": "dashboards/*/lastModified/time"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": "com.linkedin.pegasus2avro.common.Edge"
                        },
                        "name": "dashboards",
                        "default": [],
                        "doc": "Dashboards included by this dashboard.\nSome dashboard entities (e.g. PowerBI Apps) can contain other dashboards.\n\nThe Edge's sourceUrn should never be set, as it will always be the base dashboard."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.ChangeAuditStamps",
                        "name": "lastModified",
                        "doc": "Captures information about who created/last modified/deleted this dashboard and when"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "dashboardUrl",
                        "default": null,
                        "doc": "URL for the dashboard. This could be used as an external link on DataHub to allow users access/view the dashboard"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "KEYWORD",
                          "filterNameOverride": "Access Level"
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AccessLevel"
                        ],
                        "name": "access",
                        "default": null,
                        "doc": "Access level for the dashboard"
                      },
                      {
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "lastRefreshed",
                        "default": null,
                        "doc": "The time when this dashboard last refreshed"
                      }
                    ],
                    "doc": "Information about a dashboard"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "editableDashboardProperties"
                    },
                    "name": "EditableDashboardProperties",
                    "namespace": "com.linkedin.pegasus2avro.dashboard",
                    "fields": [
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "created",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "deleted",
                        "default": null,
                        "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                      },
                      {
                        "Searchable": {
                          "fieldName": "editedDescription",
                          "fieldType": "TEXT"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Edited documentation of the dashboard"
                      }
                    ],
                    "doc": "Stores editable changes made to properties. This separates changes made from\ningestion pipelines and edits in the UI to avoid accidental overwrites of user-provided data by ingestion pipelines"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.GlossaryTerms",
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the dashboard. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific Dashboard entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "dataFlowKey",
            "name": "dataFlow"
          },
          "name": "DataFlowSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.DataFlowUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "DataFlowUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataFlowKey"
                    },
                    "name": "DataFlowKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "orchestrator",
                        "doc": "Workflow manager like azkaban, airflow which orchestrates the flow"
                      },
                      {
                        "Searchable": {
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "flowId",
                        "doc": "Unique Identifier of the data flow"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "cluster",
                        "doc": "Cluster where the flow is executed"
                      }
                    ],
                    "doc": "Key for a Data Flow"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataFlowInfo"
                    },
                    "name": "DataFlowInfo",
                    "namespace": "com.linkedin.pegasus2avro.datajob",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Flow name"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Flow description"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL",
                          "queryByDefault": false
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "project",
                        "default": null,
                        "doc": "Optional project/namespace associated with the flow"
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "createdAt",
                            "fieldType": "DATETIME"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "record",
                            "name": "TimeStamp",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "fields": [
                              {
                                "type": "long",
                                "name": "time",
                                "doc": "When did the event occur"
                              },
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "actor",
                                "default": null,
                                "doc": "Optional: The actor urn involved in the event.",
                                "Urn": "Urn"
                              }
                            ],
                            "doc": "A standard event timestamp"
                          }
                        ],
                        "name": "created",
                        "default": null,
                        "doc": "A timestamp documenting when the asset was created in the source Data Platform (not on DataHub)"
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "lastModifiedAt",
                            "fieldType": "DATETIME"
                          }
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "lastModified",
                        "default": null,
                        "doc": "A timestamp documenting when the asset was last modified in the source Data Platform (not on DataHub)"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "KEYWORD",
                          "filterNameOverride": "Environment",
                          "queryByDefault": false
                        },
                        "type": [
                          "null",
                          {
                            "type": "enum",
                            "symbolDocs": {
                              "CORP": "Designates corporation fabrics",
                              "DEV": "Designates development fabrics",
                              "EI": "Designates early-integration fabrics",
                              "NON_PROD": "Designates non-production fabrics",
                              "PRE": "Designates pre-production fabrics",
                              "PROD": "Designates production fabrics",
                              "QA": "Designates quality assurance fabrics",
                              "RVW": "Designates review fabrics",
                              "SANDBOX": "Designates sandbox fabrics",
                              "STG": "Designates staging fabrics",
                              "TEST": "Designates testing fabrics",
                              "UAT": "Designates user acceptance testing fabrics"
                            },
                            "name": "FabricType",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "symbols": [
                              "DEV",
                              "TEST",
                              "QA",
                              "UAT",
                              "EI",
                              "PRE",
                              "STG",
                              "NON_PROD",
                              "PROD",
                              "CORP",
                              "RVW",
                              "SANDBOX"
                            ],
                            "doc": "Fabric group type"
                          }
                        ],
                        "name": "env",
                        "default": null,
                        "doc": "Environment for this flow"
                      }
                    ],
                    "doc": "Information about a Data processing flow"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "editableDataFlowProperties"
                    },
                    "name": "EditableDataFlowProperties",
                    "namespace": "com.linkedin.pegasus2avro.datajob",
                    "fields": [
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "created",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "deleted",
                        "default": null,
                        "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                      },
                      {
                        "Searchable": {
                          "fieldName": "editedDescription",
                          "fieldType": "TEXT"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Edited documentation of the data flow"
                      }
                    ],
                    "doc": "Stores editable changes made to properties. This separates changes made from\ningestion pipelines and edits in the UI to avoid accidental overwrites of user-provided data by ingestion pipelines"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.GlossaryTerms",
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the data flow. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific DataFlow entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "dataJobKey",
            "name": "dataJob"
          },
          "name": "DataJobSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.DataJobUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "DataJobUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataJobKey"
                    },
                    "name": "DataJobKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Relationship": {
                          "entityTypes": [
                            "dataFlow"
                          ],
                          "name": "IsPartOf"
                        },
                        "Searchable": {
                          "fieldName": "dataFlow",
                          "fieldType": "URN_PARTIAL",
                          "queryByDefault": false
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "flow",
                        "doc": "Standardized data processing flow urn representing the flow for the job",
                        "Urn": "Urn",
                        "entityTypes": [
                          "dataFlow"
                        ]
                      },
                      {
                        "Searchable": {
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "jobId",
                        "doc": "Unique Identifier of the data job"
                      }
                    ],
                    "doc": "Key for a Data Job"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataJobInfo"
                    },
                    "name": "DataJobInfo",
                    "namespace": "com.linkedin.pegasus2avro.datajob",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Job name"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Job description"
                      },
                      {
                        "type": [
                          {
                            "type": "enum",
                            "symbolDocs": {
                              "COMMAND": "The command job type is one of the basic built-in types. It runs multiple UNIX commands using java processbuilder.\nUpon execution, Azkaban spawns off a process to run the command.",
                              "GLUE": "Glue type is for running AWS Glue job transforms.",
                              "HADOOP_JAVA": "Runs a java program with ability to access Hadoop cluster.\nhttps://azkaban.readthedocs.io/en/latest/jobTypes.html#java-job-type",
                              "HADOOP_SHELL": "In large part, this is the same Command type. The difference is its ability to talk to a Hadoop cluster\nsecurely, via Hadoop tokens.",
                              "HIVE": "Hive type is for running Hive jobs.",
                              "PIG": "Pig type is for running Pig jobs.",
                              "SQL": "SQL is for running Presto, mysql queries etc"
                            },
                            "name": "AzkabanJobType",
                            "namespace": "com.linkedin.pegasus2avro.datajob.azkaban",
                            "symbols": [
                              "COMMAND",
                              "HADOOP_JAVA",
                              "HADOOP_SHELL",
                              "HIVE",
                              "PIG",
                              "SQL",
                              "GLUE"
                            ],
                            "doc": "The various types of support azkaban jobs"
                          },
                          "string"
                        ],
                        "name": "type",
                        "doc": "Datajob type\n*NOTE**: AzkabanJobType is deprecated. Please use strings instead."
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.DataFlowUrn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "flowUrn",
                        "default": null,
                        "doc": "DataFlow urn that this job is part of",
                        "Urn": "DataFlowUrn"
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "createdAt",
                            "fieldType": "DATETIME"
                          }
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "created",
                        "default": null,
                        "doc": "A timestamp documenting when the asset was created in the source Data Platform (not on DataHub)"
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "lastModifiedAt",
                            "fieldType": "DATETIME"
                          }
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "lastModified",
                        "default": null,
                        "doc": "A timestamp documenting when the asset was last modified in the source Data Platform (not on DataHub)"
                      },
                      {
                        "deprecated": "Use Data Process Instance model, instead",
                        "type": [
                          "null",
                          {
                            "type": "enum",
                            "symbolDocs": {
                              "COMPLETED": "Jobs with successful completion.",
                              "FAILED": "Jobs that have failed.",
                              "IN_PROGRESS": "Jobs currently running.",
                              "SKIPPED": "Jobs that have been skipped.",
                              "STARTING": "Jobs being initialized.",
                              "STOPPED": "Jobs that have stopped.",
                              "STOPPING": "Jobs being stopped.",
                              "UNKNOWN": "Jobs with unknown status (either unmappable or unavailable)"
                            },
                            "name": "JobStatus",
                            "namespace": "com.linkedin.pegasus2avro.datajob",
                            "symbols": [
                              "STARTING",
                              "IN_PROGRESS",
                              "STOPPING",
                              "STOPPED",
                              "COMPLETED",
                              "FAILED",
                              "UNKNOWN",
                              "SKIPPED"
                            ],
                            "doc": "Job statuses"
                          }
                        ],
                        "name": "status",
                        "default": null,
                        "doc": "Status of the job - Deprecated for Data Process Instance model."
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "KEYWORD",
                          "filterNameOverride": "Environment",
                          "queryByDefault": false
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.FabricType"
                        ],
                        "name": "env",
                        "default": null,
                        "doc": "Environment for this job"
                      }
                    ],
                    "doc": "Information about a Data processing job"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataJobInputOutput"
                    },
                    "name": "DataJobInputOutput",
                    "namespace": "com.linkedin.pegasus2avro.datajob",
                    "fields": [
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "inputs",
                            "fieldType": "URN",
                            "numValuesFieldName": "numInputDatasets",
                            "queryByDefault": false
                          }
                        },
                        "deprecated": true,
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "inputDatasets",
                        "doc": "Input datasets consumed by the data job during processing\nDeprecated! Use inputDatasetEdges instead.",
                        "Urn": "DatasetUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*/destinationUrn": {
                            "createdActor": "inputDatasetEdges/*/created/actor",
                            "createdOn": "inputDatasetEdges/*/created/time",
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes",
                            "properties": "inputDatasetEdges/*/properties",
                            "updatedActor": "inputDatasetEdges/*/lastModified/actor",
                            "updatedOn": "inputDatasetEdges/*/lastModified/time"
                          }
                        },
                        "Searchable": {
                          "/*/destinationUrn": {
                            "fieldName": "inputDatasetEdges",
                            "fieldType": "URN",
                            "numValuesFieldName": "numInputDatasets",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.common.Edge"
                          }
                        ],
                        "name": "inputDatasetEdges",
                        "default": null,
                        "doc": "Input datasets consumed by the data job during processing"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "isUpstream": false,
                            "name": "Produces"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "outputs",
                            "fieldType": "URN",
                            "numValuesFieldName": "numOutputDatasets",
                            "queryByDefault": false
                          }
                        },
                        "deprecated": true,
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "outputDatasets",
                        "doc": "Output datasets produced by the data job during processing\nDeprecated! Use outputDatasetEdges instead.",
                        "Urn": "DatasetUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*/destinationUrn": {
                            "createdActor": "outputDatasetEdges/*/created/actor",
                            "createdOn": "outputDatasetEdges/*/created/time",
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "isUpstream": false,
                            "name": "Produces",
                            "properties": "outputDatasetEdges/*/properties",
                            "updatedActor": "outputDatasetEdges/*/lastModified/actor",
                            "updatedOn": "outputDatasetEdges/*/lastModified/time"
                          }
                        },
                        "Searchable": {
                          "/*/destinationUrn": {
                            "fieldName": "outputDatasetEdges",
                            "fieldType": "URN",
                            "numValuesFieldName": "numOutputDatasets",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.common.Edge"
                          }
                        ],
                        "name": "outputDatasetEdges",
                        "default": null,
                        "doc": "Output datasets produced by the data job during processing"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataJob"
                            ],
                            "isLineage": true,
                            "name": "DownstreamOf"
                          }
                        },
                        "deprecated": true,
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "inputDatajobs",
                        "default": null,
                        "doc": "Input datajobs that this data job depends on\nDeprecated! Use inputDatajobEdges instead.",
                        "Urn": "DataJobUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*/destinationUrn": {
                            "createdActor": "inputDatajobEdges/*/created/actor",
                            "createdOn": "inputDatajobEdges/*/created/time",
                            "entityTypes": [
                              "dataJob"
                            ],
                            "isLineage": true,
                            "name": "DownstreamOf",
                            "properties": "inputDatajobEdges/*/properties",
                            "updatedActor": "inputDatajobEdges/*/lastModified/actor",
                            "updatedOn": "inputDatajobEdges/*/lastModified/time"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.common.Edge"
                          }
                        ],
                        "name": "inputDatajobEdges",
                        "default": null,
                        "doc": "Input datajobs that this data job depends on"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "schemaField"
                            ],
                            "name": "Consumes"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "inputFields",
                            "fieldType": "URN",
                            "numValuesFieldName": "numInputFields",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "inputDatasetFields",
                        "default": null,
                        "doc": "Fields of the input datasets used by this job",
                        "Urn": "Urn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "schemaField"
                            ],
                            "name": "Produces"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "outputFields",
                            "fieldType": "URN",
                            "numValuesFieldName": "numOutputFields",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "outputDatasetFields",
                        "default": null,
                        "doc": "Fields of the output datasets this job writes to",
                        "Urn": "Urn",
                        "urn_is_array": true
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": {
                              "type": "record",
                              "name": "FineGrainedLineage",
                              "namespace": "com.linkedin.pegasus2avro.dataset",
                              "fields": [
                                {
                                  "type": {
                                    "type": "enum",
                                    "symbolDocs": {
                                      "DATASET": " Indicates that this lineage is originating from upstream dataset(s)",
                                      "FIELD_SET": " Indicates that this lineage is originating from upstream field(s)",
                                      "NONE": " Indicates that there is no upstream lineage i.e. the downstream field is not a derived field"
                                    },
                                    "name": "FineGrainedLineageUpstreamType",
                                    "namespace": "com.linkedin.pegasus2avro.dataset",
                                    "symbols": [
                                      "FIELD_SET",
                                      "DATASET",
                                      "NONE"
                                    ],
                                    "doc": "The type of upstream entity in a fine-grained lineage"
                                  },
                                  "name": "upstreamType",
                                  "doc": "The type of upstream entity"
                                },
                                {
                                  "type": [
                                    "null",
                                    {
                                      "type": "array",
                                      "items": "string"
                                    }
                                  ],
                                  "name": "upstreams",
                                  "default": null,
                                  "doc": "Upstream entities in the lineage",
                                  "Urn": "Urn",
                                  "urn_is_array": true
                                },
                                {
                                  "type": {
                                    "type": "enum",
                                    "symbolDocs": {
                                      "FIELD": " Indicates that the lineage is for a single, specific, downstream field",
                                      "FIELD_SET": " Indicates that the lineage is for a set of downstream fields"
                                    },
                                    "name": "FineGrainedLineageDownstreamType",
                                    "namespace": "com.linkedin.pegasus2avro.dataset",
                                    "symbols": [
                                      "FIELD",
                                      "FIELD_SET"
                                    ],
                                    "doc": "The type of downstream field(s) in a fine-grained lineage"
                                  },
                                  "name": "downstreamType",
                                  "doc": "The type of downstream field(s)"
                                },
                                {
                                  "type": [
                                    "null",
                                    {
                                      "type": "array",
                                      "items": "string"
                                    }
                                  ],
                                  "name": "downstreams",
                                  "default": null,
                                  "doc": "Downstream fields in the lineage",
                                  "Urn": "Urn",
                                  "urn_is_array": true
                                },
                                {
                                  "type": [
                                    "null",
                                    "string"
                                  ],
                                  "name": "transformOperation",
                                  "default": null,
                                  "doc": "The transform operation applied to the upstream entities to produce the downstream field(s)"
                                },
                                {
                                  "type": "float",
                                  "name": "confidenceScore",
                                  "default": 1.0,
                                  "doc": "The confidence in this lineage between 0 (low confidence) and 1 (high confidence)"
                                },
                                {
                                  "java": {
                                    "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                  },
                                  "type": [
                                    "null",
                                    "string"
                                  ],
                                  "name": "query",
                                  "default": null,
                                  "doc": "The query that was used to generate this lineage. \nPresent only if the lineage was generated from a detected query.",
                                  "Urn": "Urn"
                                }
                              ],
                              "doc": "A fine-grained lineage from upstream fields/datasets to downstream field(s)"
                            }
                          }
                        ],
                        "name": "fineGrainedLineages",
                        "default": null,
                        "doc": "Fine-grained column-level lineages\nNot currently supported in the UI\nUse UpstreamLineage aspect for datasets to express Column Level Lineage for the UI"
                      }
                    ],
                    "doc": "Information about the inputs and outputs of a Data processing job"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "editableDataJobProperties"
                    },
                    "name": "EditableDataJobProperties",
                    "namespace": "com.linkedin.pegasus2avro.datajob",
                    "fields": [
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "created",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "deleted",
                        "default": null,
                        "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                      },
                      {
                        "Searchable": {
                          "fieldName": "editedDescription",
                          "fieldType": "TEXT"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Edited documentation of the data job "
                      }
                    ],
                    "doc": "Stores editable changes made to properties. This separates changes made from\ningestion pipelines and edits in the UI to avoid accidental overwrites of user-provided data by ingestion pipelines"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.GlossaryTerms",
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the data job. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific DataJob entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "datasetKey",
            "name": "dataset"
          },
          "name": "DatasetSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.DatasetUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "DatasetUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "datasetKey"
                    },
                    "name": "DatasetKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "enableAutocomplete": true,
                          "fieldType": "URN"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "platform",
                        "doc": "Data platform urn associated with the dataset",
                        "Urn": "Urn"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldName": "id",
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Unique guid for dataset"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "TEXT_PARTIAL",
                          "filterNameOverride": "Environment",
                          "queryByDefault": false
                        },
                        "type": "com.linkedin.pegasus2avro.common.FabricType",
                        "name": "origin",
                        "doc": "Fabric type where dataset belongs to or where it was generated."
                      }
                    ],
                    "doc": "Key for a Dataset"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "datasetProperties"
                    },
                    "name": "DatasetProperties",
                    "namespace": "com.linkedin.pegasus2avro.dataset",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "name",
                        "default": null,
                        "doc": "Display name of the Dataset"
                      },
                      {
                        "Searchable": {
                          "addToFilters": false,
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "qualifiedName",
                        "default": null,
                        "doc": "Fully-qualified name of the Dataset"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the dataset"
                      },
                      {
                        "deprecated": "Use ExternalReference.externalUrl field instead.",
                        "java": {
                          "class": "java.net.URI"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "uri",
                        "default": null,
                        "doc": "The abstracted URI such as hdfs:///data/tracking/PageViewEvent, file:///dir/file_name. Uri should not include any environment specific properties. Some datasets might not have a standardized uri, which makes this field optional (i.e. kafka topic)."
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "createdAt",
                            "fieldType": "DATETIME"
                          }
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "created",
                        "default": null,
                        "doc": "A timestamp documenting when the asset was created in the source Data Platform (not on DataHub)"
                      },
                      {
                        "Searchable": {
                          "/time": {
                            "fieldName": "lastModifiedAt",
                            "fieldType": "DATETIME"
                          }
                        },
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "lastModified",
                        "default": null,
                        "doc": "A timestamp documenting when the asset was last modified in the source Data Platform (not on DataHub)"
                      },
                      {
                        "deprecated": "Use GlobalTags aspect instead.",
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "tags",
                        "default": [],
                        "doc": "[Legacy] Unstructured tags for the dataset. Structured tags can be applied via the `GlobalTags` aspect.\nThis is now deprecated."
                      }
                    ],
                    "doc": "Properties associated with a Dataset"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "editableDatasetProperties"
                    },
                    "name": "EditableDatasetProperties",
                    "namespace": "com.linkedin.pegasus2avro.dataset",
                    "fields": [
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "created",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "deleted",
                        "default": null,
                        "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                      },
                      {
                        "Searchable": {
                          "fieldName": "editedDescription",
                          "fieldType": "TEXT"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the dataset"
                      },
                      {
                        "Searchable": {
                          "fieldName": "editedName",
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "name",
                        "default": null,
                        "doc": "Editable display name of the Dataset"
                      }
                    ],
                    "doc": "EditableDatasetProperties stores editable changes made to dataset properties. This separates changes made from\ningestion pipelines and edits in the UI to avoid accidental overwrites of user-provided data by ingestion pipelines"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "datasetDeprecation"
                    },
                    "Deprecated": true,
                    "name": "DatasetDeprecation",
                    "namespace": "com.linkedin.pegasus2avro.dataset",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "BOOLEAN",
                          "weightsPerFieldValue": {
                            "true": 0.5
                          }
                        },
                        "type": "boolean",
                        "name": "deprecated",
                        "doc": "Whether the dataset is deprecated by owner."
                      },
                      {
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "decommissionTime",
                        "default": null,
                        "doc": "The time user plan to decommission this dataset."
                      },
                      {
                        "type": "string",
                        "name": "note",
                        "doc": "Additional information about the dataset deprecation plan, such as the wiki, doc, RB."
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "actor",
                        "default": null,
                        "doc": "The corpuser URN which will be credited for modifying this deprecation content.",
                        "Urn": "Urn"
                      }
                    ],
                    "doc": "Dataset deprecation status\nDeprecated! This aspect is deprecated in favor of the more-general-purpose 'Deprecation' aspect."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "datasetUpstreamLineage"
                    },
                    "deprecated": "use UpstreamLineage.fineGrainedLineages instead",
                    "name": "DatasetUpstreamLineage",
                    "namespace": "com.linkedin.pegasus2avro.dataset",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "deprecated": "use FineGrainedLineage instead",
                            "name": "DatasetFieldMapping",
                            "namespace": "com.linkedin.pegasus2avro.dataset",
                            "fields": [
                              {
                                "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                                "name": "created",
                                "doc": "Audit stamp containing who reported the field mapping and when"
                              },
                              {
                                "type": [
                                  {
                                    "type": "enum",
                                    "symbolDocs": {
                                      "BLACKBOX": "Field transformation expressed as unknown black box function.",
                                      "IDENTITY": "Field transformation expressed as Identity function."
                                    },
                                    "name": "TransformationType",
                                    "namespace": "com.linkedin.pegasus2avro.common.fieldtransformer",
                                    "symbols": [
                                      "BLACKBOX",
                                      "IDENTITY"
                                    ],
                                    "doc": "Type of the transformation involved in generating destination fields from source fields."
                                  },
                                  {
                                    "type": "record",
                                    "name": "UDFTransformer",
                                    "namespace": "com.linkedin.pegasus2avro.common.fieldtransformer",
                                    "fields": [
                                      {
                                        "type": "string",
                                        "name": "udf",
                                        "doc": "A UDF mentioning how the source fields got transformed to destination field. This is the FQCN(Fully Qualified Class Name) of the udf."
                                      }
                                    ],
                                    "doc": "Field transformation expressed in UDF"
                                  }
                                ],
                                "name": "transformation",
                                "doc": "Transfomration function between the fields involved"
                              },
                              {
                                "type": {
                                  "type": "array",
                                  "items": [
                                    "string"
                                  ]
                                },
                                "name": "sourceFields",
                                "doc": "Source fields from which the fine grained lineage is derived"
                              },
                              {
                                "deprecated": "use SchemaFieldPath and represent as generic Urn instead",
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.DatasetFieldUrn"
                                },
                                "type": "string",
                                "name": "destinationField",
                                "doc": "Destination field which is derived from source fields",
                                "Urn": "DatasetFieldUrn"
                              }
                            ],
                            "doc": "Representation of mapping between fields in source dataset to the field in destination dataset"
                          }
                        },
                        "name": "fieldMappings",
                        "doc": "Upstream to downstream field level lineage mappings"
                      }
                    ],
                    "doc": "Fine Grained upstream lineage for fields in a dataset"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "upstreamLineage"
                    },
                    "name": "UpstreamLineage",
                    "namespace": "com.linkedin.pegasus2avro.dataset",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "Upstream",
                            "namespace": "com.linkedin.pegasus2avro.dataset",
                            "fields": [
                              {
                                "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                                "name": "auditStamp",
                                "default": {
                                  "actor": "urn:li:corpuser:unknown",
                                  "impersonator": null,
                                  "time": 0,
                                  "message": null
                                },
                                "doc": "Audit stamp containing who reported the lineage and when."
                              },
                              {
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.AuditStamp"
                                ],
                                "name": "created",
                                "default": null,
                                "doc": "Audit stamp containing who created the lineage and when."
                              },
                              {
                                "Relationship": {
                                  "createdActor": "upstreams/*/created/actor",
                                  "createdOn": "upstreams/*/created/time",
                                  "entityTypes": [
                                    "dataset"
                                  ],
                                  "isLineage": true,
                                  "name": "DownstreamOf",
                                  "properties": "upstreams/*/properties",
                                  "updatedActor": "upstreams/*/auditStamp/actor",
                                  "updatedOn": "upstreams/*/auditStamp/time",
                                  "via": "upstreams/*/query"
                                },
                                "Searchable": {
                                  "fieldName": "upstreams",
                                  "fieldType": "URN",
                                  "queryByDefault": false
                                },
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.DatasetUrn"
                                },
                                "type": "string",
                                "name": "dataset",
                                "doc": "The upstream dataset the lineage points to",
                                "Urn": "DatasetUrn",
                                "entityTypes": [
                                  "dataset"
                                ]
                              },
                              {
                                "type": {
                                  "type": "enum",
                                  "symbolDocs": {
                                    "COPY": "Direct copy without modification",
                                    "TRANSFORMED": "Transformed data with modification (format or content change)",
                                    "VIEW": "Represents a view defined on the sources e.g. Hive view defined on underlying hive tables or a Hive table pointing to a HDFS dataset or DALI view defined on multiple sources"
                                  },
                                  "name": "DatasetLineageType",
                                  "namespace": "com.linkedin.pegasus2avro.dataset",
                                  "symbols": [
                                    "COPY",
                                    "TRANSFORMED",
                                    "VIEW"
                                  ],
                                  "doc": "The various types of supported dataset lineage"
                                },
                                "name": "type",
                                "doc": "The type of the lineage"
                              },
                              {
                                "type": [
                                  "null",
                                  {
                                    "type": "map",
                                    "values": "string"
                                  }
                                ],
                                "name": "properties",
                                "default": null,
                                "doc": "A generic properties bag that allows us to store specific information on this graph edge."
                              },
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "query",
                                "default": null,
                                "doc": "If the lineage is generated by a query, a reference to the query",
                                "Urn": "Urn"
                              }
                            ],
                            "doc": "Upstream lineage information about a dataset including the source reporting the lineage"
                          }
                        },
                        "name": "upstreams",
                        "doc": "List of upstream dataset lineage information"
                      },
                      {
                        "Relationship": {
                          "/*/upstreams/*": {
                            "entityTypes": [
                              "dataset",
                              "schemaField"
                            ],
                            "name": "DownstreamOf"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.dataset.FineGrainedLineage"
                          }
                        ],
                        "name": "fineGrainedLineages",
                        "default": null,
                        "doc": " List of fine-grained lineage information, including field-level lineage"
                      }
                    ],
                    "doc": "Upstream lineage of a dataset"
                  },
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "schemaMetadata"
                    },
                    "name": "SchemaMetadata",
                    "namespace": "com.linkedin.pegasus2avro.schema",
                    "fields": [
                      {
                        "validate": {
                          "strlen": {
                            "max": 500,
                            "min": 1
                          }
                        },
                        "type": "string",
                        "name": "schemaName",
                        "doc": "Schema name e.g. PageViewEvent, identity.Profile, ams.account_management_tracking"
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.DataPlatformUrn"
                        },
                        "type": "string",
                        "name": "platform",
                        "doc": "Standardized platform urn where schema is defined. The data platform Urn (urn:li:platform:{platform_name})",
                        "Urn": "DataPlatformUrn"
                      },
                      {
                        "type": "long",
                        "name": "version",
                        "doc": "Every change to SchemaMetadata in the resource results in a new version. Version is server assigned. This version is differ from platform native schema version."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "created",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "deleted",
                        "default": null,
                        "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.DatasetUrn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "dataset",
                        "default": null,
                        "doc": "Dataset this schema metadata is associated with.",
                        "Urn": "DatasetUrn"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "cluster",
                        "default": null,
                        "doc": "The cluster this schema metadata resides from"
                      },
                      {
                        "type": "string",
                        "name": "hash",
                        "doc": "the SHA1 hash of the schema content"
                      },
                      {
                        "type": [
                          {
                            "type": "record",
                            "name": "EspressoSchema",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "documentSchema",
                                "doc": "The native espresso document schema."
                              },
                              {
                                "type": "string",
                                "name": "tableSchema",
                                "doc": "The espresso table schema definition."
                              }
                            ],
                            "doc": "Schema text of an espresso table schema."
                          },
                          {
                            "type": "record",
                            "name": "OracleDDL",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "tableSchema",
                                "doc": "The native schema in the dataset's platform. This is a human readable (json blob) table schema."
                              }
                            ],
                            "doc": "Schema holder for oracle data definition language that describes an oracle table."
                          },
                          {
                            "type": "record",
                            "name": "MySqlDDL",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "tableSchema",
                                "doc": "The native schema in the dataset's platform. This is a human readable (json blob) table schema."
                              }
                            ],
                            "doc": "Schema holder for MySql data definition language that describes an MySql table."
                          },
                          {
                            "type": "record",
                            "name": "PrestoDDL",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "rawSchema",
                                "doc": "The raw schema in the dataset's platform. This includes the DDL and the columns extracted from DDL."
                              }
                            ],
                            "doc": "Schema holder for presto data definition language that describes a presto view."
                          },
                          {
                            "type": "record",
                            "name": "KafkaSchema",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "documentSchema",
                                "doc": "The native kafka document schema. This is a human readable avro document schema."
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "documentSchemaType",
                                "default": null,
                                "doc": "The native kafka document schema type. This can be AVRO/PROTOBUF/JSON."
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "keySchema",
                                "default": null,
                                "doc": "The native kafka key schema as retrieved from Schema Registry"
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "keySchemaType",
                                "default": null,
                                "doc": "The native kafka key schema type. This can be AVRO/PROTOBUF/JSON."
                              }
                            ],
                            "doc": "Schema holder for kafka schema."
                          },
                          {
                            "type": "record",
                            "name": "BinaryJsonSchema",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "schema",
                                "doc": "The native schema text for binary JSON file format."
                              }
                            ],
                            "doc": "Schema text of binary JSON schema."
                          },
                          {
                            "type": "record",
                            "name": "OrcSchema",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "schema",
                                "doc": "The native schema for ORC file format."
                              }
                            ],
                            "doc": "Schema text of an ORC schema."
                          },
                          {
                            "type": "record",
                            "name": "Schemaless",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [],
                            "doc": "The dataset has no specific schema associated with it"
                          },
                          {
                            "type": "record",
                            "name": "KeyValueSchema",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "keySchema",
                                "doc": "The raw schema for the key in the key-value store."
                              },
                              {
                                "type": "string",
                                "name": "valueSchema",
                                "doc": "The raw schema for the value in the key-value store."
                              }
                            ],
                            "doc": "Schema text of a key-value store schema."
                          },
                          {
                            "type": "record",
                            "name": "OtherSchema",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "rawSchema",
                                "doc": "The native schema in the dataset's platform."
                              }
                            ],
                            "doc": "Schema holder for undefined schema types."
                          }
                        ],
                        "name": "platformSchema",
                        "doc": "The native schema in the dataset's platform."
                      },
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "SchemaField",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "Searchable": {
                                  "boostScore": 1.0,
                                  "fieldName": "fieldPaths",
                                  "fieldType": "TEXT",
                                  "queryByDefault": "true"
                                },
                                "type": "string",
                                "name": "fieldPath",
                                "doc": "Flattened name of the field. Field is computed from jsonPath field."
                              },
                              {
                                "Deprecated": true,
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "jsonPath",
                                "default": null,
                                "doc": "Flattened name of a field in JSON Path notation."
                              },
                              {
                                "type": "boolean",
                                "name": "nullable",
                                "default": false,
                                "doc": "Indicates if this field is optional or nullable"
                              },
                              {
                                "Searchable": {
                                  "boostScore": 0.1,
                                  "fieldName": "fieldDescriptions",
                                  "fieldType": "TEXT"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "description",
                                "default": null,
                                "doc": "Description"
                              },
                              {
                                "Deprecated": true,
                                "Searchable": {
                                  "boostScore": 0.2,
                                  "fieldName": "fieldLabels",
                                  "fieldType": "TEXT"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "label",
                                "default": null,
                                "doc": "Label of the field. Provides a more human-readable name for the field than field path. Some sources will\nprovide this metadata but not all sources have the concept of a label. If just one string is associated with\na field in a source, that is most likely a description.\n\nNote that this field is deprecated and is not surfaced in the UI."
                              },
                              {
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.AuditStamp"
                                ],
                                "name": "created",
                                "default": null,
                                "doc": "An AuditStamp corresponding to the creation of this schema field."
                              },
                              {
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.AuditStamp"
                                ],
                                "name": "lastModified",
                                "default": null,
                                "doc": "An AuditStamp corresponding to the last modification of this schema field."
                              },
                              {
                                "type": {
                                  "type": "record",
                                  "name": "SchemaFieldDataType",
                                  "namespace": "com.linkedin.pegasus2avro.schema",
                                  "fields": [
                                    {
                                      "type": [
                                        {
                                          "type": "record",
                                          "name": "BooleanType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Boolean field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "FixedType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Fixed field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "StringType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "String field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "BytesType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Bytes field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "NumberType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Number data type: long, integer, short, etc.."
                                        },
                                        {
                                          "type": "record",
                                          "name": "DateType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Date field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "TimeType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Time field type. This should also be used for datetimes."
                                        },
                                        {
                                          "type": "record",
                                          "name": "EnumType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Enum field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "NullType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Null field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "MapType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [
                                            {
                                              "type": [
                                                "null",
                                                "string"
                                              ],
                                              "name": "keyType",
                                              "default": null,
                                              "doc": "Key type in a map"
                                            },
                                            {
                                              "type": [
                                                "null",
                                                "string"
                                              ],
                                              "name": "valueType",
                                              "default": null,
                                              "doc": "Type of the value in a map"
                                            }
                                          ],
                                          "doc": "Map field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "ArrayType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [
                                            {
                                              "type": [
                                                "null",
                                                {
                                                  "type": "array",
                                                  "items": "string"
                                                }
                                              ],
                                              "name": "nestedType",
                                              "default": null,
                                              "doc": "List of types this array holds."
                                            }
                                          ],
                                          "doc": "Array field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "UnionType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [
                                            {
                                              "type": [
                                                "null",
                                                {
                                                  "type": "array",
                                                  "items": "string"
                                                }
                                              ],
                                              "name": "nestedTypes",
                                              "default": null,
                                              "doc": "List of types in union type."
                                            }
                                          ],
                                          "doc": "Union field type."
                                        },
                                        {
                                          "type": "record",
                                          "name": "RecordType",
                                          "namespace": "com.linkedin.pegasus2avro.schema",
                                          "fields": [],
                                          "doc": "Record field type."
                                        }
                                      ],
                                      "name": "type",
                                      "doc": "Data platform specific types"
                                    }
                                  ],
                                  "doc": "Schema field data types"
                                },
                                "name": "type",
                                "doc": "Platform independent field type of the field."
                              },
                              {
                                "type": "string",
                                "name": "nativeDataType",
                                "doc": "The native type of the field in the dataset's platform as declared by platform schema."
                              },
                              {
                                "type": "boolean",
                                "name": "recursive",
                                "default": false,
                                "doc": "There are use cases when a field in type B references type A. A field in A references field of type B. In such cases, we will mark the first field as recursive."
                              },
                              {
                                "Relationship": {
                                  "/tags/*/tag": {
                                    "entityTypes": [
                                      "tag"
                                    ],
                                    "name": "SchemaFieldTaggedWith"
                                  }
                                },
                                "Searchable": {
                                  "/tags/*/attribution/actor": {
                                    "fieldName": "fieldTagAttributionActors",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/tags/*/attribution/source": {
                                    "fieldName": "fieldTagAttributionSources",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/tags/*/attribution/time": {
                                    "fieldName": "fieldTagAttributionDates",
                                    "fieldType": "DATETIME",
                                    "queryByDefault": false
                                  },
                                  "/tags/*/tag": {
                                    "boostScore": 0.5,
                                    "fieldName": "fieldTags",
                                    "fieldType": "URN"
                                  }
                                },
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.GlobalTags"
                                ],
                                "name": "globalTags",
                                "default": null,
                                "doc": "Tags associated with the field"
                              },
                              {
                                "Relationship": {
                                  "/terms/*/urn": {
                                    "entityTypes": [
                                      "glossaryTerm"
                                    ],
                                    "name": "SchemaFieldWithGlossaryTerm"
                                  }
                                },
                                "Searchable": {
                                  "/terms/*/attribution/actor": {
                                    "fieldName": "fieldTermAttributionActors",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/terms/*/attribution/source": {
                                    "fieldName": "fieldTermAttributionSources",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/terms/*/attribution/time": {
                                    "fieldName": "fieldTermAttributionDates",
                                    "fieldType": "DATETIME",
                                    "queryByDefault": false
                                  },
                                  "/terms/*/urn": {
                                    "boostScore": 0.5,
                                    "fieldName": "fieldGlossaryTerms",
                                    "fieldType": "URN"
                                  }
                                },
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.GlossaryTerms"
                                ],
                                "name": "glossaryTerms",
                                "default": null,
                                "doc": "Glossary terms associated with the field"
                              },
                              {
                                "type": "boolean",
                                "name": "isPartOfKey",
                                "default": false,
                                "doc": "For schema fields that are part of complex keys, set this field to true\nWe do this to easily distinguish between value and key fields"
                              },
                              {
                                "type": [
                                  "null",
                                  "boolean"
                                ],
                                "name": "isPartitioningKey",
                                "default": null,
                                "doc": "For Datasets which are partitioned, this determines the partitioning key.\nNote that multiple columns can be part of a partitioning key, but currently we do not support\nrendering the ordered partitioning key."
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "jsonProps",
                                "default": null,
                                "doc": "For schema fields that have other properties that are not modeled explicitly,\nuse this field to serialize those properties into a JSON string"
                              }
                            ],
                            "doc": "SchemaField to describe metadata related to dataset schema."
                          }
                        },
                        "name": "fields",
                        "doc": "Client provided a list of fields from document schema."
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "primaryKeys",
                        "default": null,
                        "doc": "Client provided list of fields that define primary keys to access record. Field order defines hierarchical espresso keys. Empty lists indicates absence of primary key access patter. Value is a SchemaField@fieldPath."
                      },
                      {
                        "deprecated": "Use foreignKeys instead.",
                        "type": [
                          "null",
                          {
                            "type": "map",
                            "values": {
                              "type": "record",
                              "name": "ForeignKeySpec",
                              "namespace": "com.linkedin.pegasus2avro.schema",
                              "fields": [
                                {
                                  "type": [
                                    {
                                      "type": "record",
                                      "name": "DatasetFieldForeignKey",
                                      "namespace": "com.linkedin.pegasus2avro.schema",
                                      "fields": [
                                        {
                                          "java": {
                                            "class": "com.linkedin.pegasus2avro.common.urn.DatasetUrn"
                                          },
                                          "type": "string",
                                          "name": "parentDataset",
                                          "doc": "dataset that stores the resource.",
                                          "Urn": "DatasetUrn"
                                        },
                                        {
                                          "type": {
                                            "type": "array",
                                            "items": "string"
                                          },
                                          "name": "currentFieldPaths",
                                          "doc": "List of fields in hosting(current) SchemaMetadata that conform a foreign key. List can contain a single entry or multiple entries if several entries in hosting schema conform a foreign key in a single parent dataset."
                                        },
                                        {
                                          "type": "string",
                                          "name": "parentField",
                                          "doc": "SchemaField@fieldPath that uniquely identify field in parent dataset that this field references."
                                        }
                                      ],
                                      "doc": "For non-urn based foregin keys."
                                    },
                                    {
                                      "type": "record",
                                      "name": "UrnForeignKey",
                                      "namespace": "com.linkedin.pegasus2avro.schema",
                                      "fields": [
                                        {
                                          "type": "string",
                                          "name": "currentFieldPath",
                                          "doc": "Field in hosting(current) SchemaMetadata."
                                        }
                                      ],
                                      "doc": "If SchemaMetadata fields make any external references and references are of type com.linkedin.pegasus2avro.common.Urn or any children, this models can be used to mark it."
                                    }
                                  ],
                                  "name": "foreignKey",
                                  "doc": "Foreign key definition in metadata schema."
                                }
                              ],
                              "doc": "Description of a foreign key in a schema."
                            }
                          }
                        ],
                        "name": "foreignKeysSpecs",
                        "default": null,
                        "doc": "Map captures all the references schema makes to external datasets. Map key is ForeignKeySpecName typeref."
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": {
                              "type": "record",
                              "name": "ForeignKeyConstraint",
                              "namespace": "com.linkedin.pegasus2avro.schema",
                              "fields": [
                                {
                                  "type": "string",
                                  "name": "name",
                                  "doc": "Name of the constraint, likely provided from the source"
                                },
                                {
                                  "Relationship": {
                                    "/*": {
                                      "entityTypes": [
                                        "schemaField"
                                      ],
                                      "name": "ForeignKeyTo"
                                    }
                                  },
                                  "type": {
                                    "type": "array",
                                    "items": "string"
                                  },
                                  "name": "foreignFields",
                                  "doc": "Fields the constraint maps to on the foreign dataset",
                                  "Urn": "Urn",
                                  "urn_is_array": true
                                },
                                {
                                  "type": {
                                    "type": "array",
                                    "items": "string"
                                  },
                                  "name": "sourceFields",
                                  "doc": "Fields the constraint maps to on the source dataset",
                                  "Urn": "Urn",
                                  "urn_is_array": true
                                },
                                {
                                  "Relationship": {
                                    "entityTypes": [
                                      "dataset"
                                    ],
                                    "name": "ForeignKeyToDataset"
                                  },
                                  "java": {
                                    "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                                  },
                                  "type": "string",
                                  "name": "foreignDataset",
                                  "doc": "Reference to the foreign dataset for ease of lookup",
                                  "Urn": "Urn",
                                  "entityTypes": [
                                    "dataset"
                                  ]
                                }
                              ],
                              "doc": "Description of a foreign key constraint in a schema."
                            }
                          }
                        ],
                        "name": "foreignKeys",
                        "default": null,
                        "doc": "List of foreign key constraints for the schema"
                      }
                    ],
                    "doc": "SchemaMetadata to describe metadata related to store schema"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "editableSchemaMetadata"
                    },
                    "name": "EditableSchemaMetadata",
                    "namespace": "com.linkedin.pegasus2avro.schema",
                    "fields": [
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "created",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the creation of this resource/association/sub-resource. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": "com.linkedin.pegasus2avro.common.AuditStamp",
                        "name": "lastModified",
                        "default": {
                          "actor": "urn:li:corpuser:unknown",
                          "impersonator": null,
                          "time": 0,
                          "message": null
                        },
                        "doc": "An AuditStamp corresponding to the last modification of this resource/association/sub-resource. If no modification has happened since creation, lastModified should be the same as created. A value of 0 for time indicates missing data."
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.AuditStamp"
                        ],
                        "name": "deleted",
                        "default": null,
                        "doc": "An AuditStamp corresponding to the deletion of this resource/association/sub-resource. Logically, deleted MUST have a later timestamp than creation. It may or may not have the same time as lastModified depending upon the resource/association/sub-resource semantics."
                      },
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "EditableSchemaFieldInfo",
                            "namespace": "com.linkedin.pegasus2avro.schema",
                            "fields": [
                              {
                                "type": "string",
                                "name": "fieldPath",
                                "doc": "FieldPath uniquely identifying the SchemaField this metadata is associated with"
                              },
                              {
                                "Searchable": {
                                  "boostScore": 0.1,
                                  "fieldName": "editedFieldDescriptions",
                                  "fieldType": "TEXT"
                                },
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "description",
                                "default": null,
                                "doc": "Description"
                              },
                              {
                                "Relationship": {
                                  "/tags/*/tag": {
                                    "entityTypes": [
                                      "tag"
                                    ],
                                    "name": "EditableSchemaFieldTaggedWith"
                                  }
                                },
                                "Searchable": {
                                  "/tags/*/attribution/actor": {
                                    "fieldName": "editedFieldTagAttributionActors",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/tags/*/attribution/source": {
                                    "fieldName": "editedFieldTagAttributionSources",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/tags/*/attribution/time": {
                                    "fieldName": "editedFieldTagAttributionDates",
                                    "fieldType": "DATETIME"
                                  },
                                  "/tags/*/tag": {
                                    "boostScore": 0.5,
                                    "fieldName": "editedFieldTags",
                                    "fieldType": "URN"
                                  }
                                },
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.GlobalTags"
                                ],
                                "name": "globalTags",
                                "default": null,
                                "doc": "Tags associated with the field"
                              },
                              {
                                "Relationship": {
                                  "/terms/*/urn": {
                                    "entityTypes": [
                                      "glossaryTerm"
                                    ],
                                    "name": "EditableSchemaFieldWithGlossaryTerm"
                                  }
                                },
                                "Searchable": {
                                  "/terms/*/attribution/actor": {
                                    "fieldName": "editedFieldTermAttributionActors",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/terms/*/attribution/source": {
                                    "fieldName": "editedFieldTermAttributionSources",
                                    "fieldType": "URN",
                                    "queryByDefault": false
                                  },
                                  "/terms/*/attribution/time": {
                                    "fieldName": "editedFieldTermAttributionDates",
                                    "fieldType": "DATETIME"
                                  },
                                  "/terms/*/urn": {
                                    "boostScore": 0.5,
                                    "fieldName": "editedFieldGlossaryTerms",
                                    "fieldType": "URN",
                                    "includeSystemModifiedAt": true,
                                    "systemModifiedAtFieldName": "schemaFieldTermsModifiedAt"
                                  }
                                },
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.GlossaryTerms"
                                ],
                                "name": "glossaryTerms",
                                "default": null,
                                "doc": "Glossary terms associated with the field"
                              }
                            ],
                            "doc": "SchemaField to describe metadata related to dataset schema."
                          }
                        },
                        "name": "editableSchemaFieldInfo",
                        "doc": "Client provided a list of fields from document schema."
                      }
                    ],
                    "doc": "EditableSchemaMetadata stores editable changes made to schema metadata. This separates changes made from\ningestion pipelines and edits in the UI to avoid accidental overwrites of user-provided data by ingestion pipelines."
                  },
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.GlossaryTerms",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "viewProperties"
                    },
                    "name": "ViewProperties",
                    "namespace": "com.linkedin.pegasus2avro.dataset",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "BOOLEAN",
                          "weightsPerFieldValue": {
                            "true": 0.5
                          }
                        },
                        "type": "boolean",
                        "name": "materialized",
                        "doc": "Whether the view is materialized"
                      },
                      {
                        "type": "string",
                        "name": "viewLogic",
                        "doc": "The view logic"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "formattedViewLogic",
                        "default": null,
                        "doc": "The formatted view logic. This is particularly used for SQL sources, where the SQL\nlogic is formatted for better readability, and with dbt, where this contains the\ncompiled SQL logic."
                      },
                      {
                        "type": "string",
                        "name": "viewLanguage",
                        "doc": "The view logic language / dialect"
                      }
                    ],
                    "doc": "Details about a View. \ne.g. Gets activated when subTypes is view"
                  },
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the dataset. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific dataset entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "dataProcessKey",
            "name": "dataProcess"
          },
          "deprecated": "Use DataJob instead.",
          "name": "DataProcessSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.DataProcessUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "DataProcessUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataProcessKey"
                    },
                    "name": "DataProcessKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 4.0,
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Process name i.e. an ETL job name"
                      },
                      {
                        "Searchable": {
                          "enableAutocomplete": true,
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "orchestrator",
                        "doc": "Standardized Orchestrator where data process is defined.\nTODO: Migrate towards something that can be validated like DataPlatform urn"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL",
                          "queryByDefault": false
                        },
                        "type": "com.linkedin.pegasus2avro.common.FabricType",
                        "name": "origin",
                        "doc": "Fabric type where dataset belongs to or where it was generated."
                      }
                    ],
                    "doc": "Key for a Data Process"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataProcessInfo"
                    },
                    "name": "DataProcessInfo",
                    "namespace": "com.linkedin.pegasus2avro.dataprocess",
                    "fields": [
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "inputs",
                            "fieldType": "URN",
                            "numValuesFieldName": "numInputDatasets",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "inputs",
                        "default": null,
                        "doc": "the inputs of the data process",
                        "Urn": "DatasetUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "Consumes"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "outputs",
                            "fieldType": "URN",
                            "numValuesFieldName": "numOutputDatasets",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "outputs",
                        "default": null,
                        "doc": "the outputs of the data process",
                        "Urn": "DatasetUrn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "The inputs and outputs of this data process"
                  },
                  "com.linkedin.pegasus2avro.common.Status"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the data process. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific Data process entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "dataPlatformKey",
            "name": "dataPlatform"
          },
          "name": "DataPlatformSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.DataPlatformUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "DataPlatformUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataPlatformKey"
                    },
                    "name": "DataPlatformKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "type": "string",
                        "name": "platformName",
                        "doc": "Data platform name i.e. hdfs, oracle, espresso"
                      }
                    ],
                    "doc": "Key for a Data Platform"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataPlatformInfo"
                    },
                    "name": "DataPlatformInfo",
                    "namespace": "com.linkedin.pegasus2avro.dataplatform",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": false,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "validate": {
                          "strlen": {
                            "max": 15
                          }
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Name of the data platform"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "displayName",
                        "default": null,
                        "doc": "The name that will be used for displaying a platform type."
                      },
                      {
                        "type": {
                          "type": "enum",
                          "symbolDocs": {
                            "FILE_SYSTEM": "Value for a file system, e.g. hdfs",
                            "KEY_VALUE_STORE": "Value for a key value store, e.g. espresso, voldemort",
                            "MESSAGE_BROKER": "Value for a message broker, e.g. kafka",
                            "OBJECT_STORE": "Value for an object store, e.g. ambry",
                            "OLAP_DATASTORE": "Value for an OLAP datastore, e.g. pinot",
                            "OTHERS": "Value for other platforms, e.g salesforce, dovetail",
                            "QUERY_ENGINE": "Value for a query engine, e.g. presto",
                            "RELATIONAL_DB": "Value for a relational database, e.g. oracle, mysql",
                            "SEARCH_ENGINE": "Value for a search engine, e.g seas"
                          },
                          "name": "PlatformType",
                          "namespace": "com.linkedin.pegasus2avro.dataplatform",
                          "symbols": [
                            "FILE_SYSTEM",
                            "KEY_VALUE_STORE",
                            "MESSAGE_BROKER",
                            "OBJECT_STORE",
                            "OLAP_DATASTORE",
                            "OTHERS",
                            "QUERY_ENGINE",
                            "RELATIONAL_DB",
                            "SEARCH_ENGINE"
                          ],
                          "doc": "Platform types available at LinkedIn"
                        },
                        "name": "type",
                        "doc": "Platform type this data platform describes"
                      },
                      {
                        "type": "string",
                        "name": "datasetNameDelimiter",
                        "doc": "The delimiter in the dataset names on the data platform, e.g. '/' for HDFS and '.' for Oracle"
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "logoUrl",
                        "default": null,
                        "doc": "The URL for a logo associated with the platform"
                      }
                    ],
                    "doc": "Information about a data platform"
                  }
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the data platform. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific dataplatform entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "mlModelKey",
            "name": "mlModel"
          },
          "name": "MLModelSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.MLModelUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "MLModelUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelKey"
                    },
                    "name": "MLModelKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "platform",
                        "doc": "Standardized platform urn for the model",
                        "Urn": "Urn"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Name of the MLModel"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "TEXT_PARTIAL",
                          "filterNameOverride": "Environment",
                          "queryByDefault": false
                        },
                        "type": "com.linkedin.pegasus2avro.common.FabricType",
                        "name": "origin",
                        "doc": "Fabric type where model belongs to or where it was generated"
                      }
                    ],
                    "doc": "Key for an ML model"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelProperties"
                    },
                    "name": "MLModelProperties",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataJob",
                              "dataProcessInstance"
                            ],
                            "isLineage": true,
                            "name": "TrainedBy"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "trainingJobs",
                        "default": null,
                        "doc": "List of jobs or process instances (if any) used to train the model or group. Visible in Lineage. Note that ML Models can also be specified as the output of a specific Data Process Instances (runs) via the DataProcessInstanceOutputs aspect."
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataJob",
                              "dataProcessInstance"
                            ],
                            "isLineage": true,
                            "isUpstream": false,
                            "name": "UsedBy"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "downstreamJobs",
                        "default": null,
                        "doc": "List of jobs or process instances (if any) that use the model or group."
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "name",
                        "default": null,
                        "doc": "Display name of the MLModel"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the MLModel"
                      },
                      {
                        "deprecated": true,
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "date",
                        "default": null,
                        "doc": "Date when the MLModel was developed"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "created",
                        "default": null,
                        "doc": "Audit stamp containing who created this and when"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "lastModified",
                        "default": null,
                        "doc": "Date when the MLModel was last modified"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "record",
                            "name": "VersionTag",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "fields": [
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "versionTag",
                                "default": null
                              },
                              {
                                "type": [
                                  "null",
                                  "com.linkedin.pegasus2avro.common.MetadataAttribution"
                                ],
                                "name": "metadataAttribution",
                                "default": null
                              }
                            ],
                            "doc": "A resource-defined string representing the resource state for the purpose of concurrency control"
                          }
                        ],
                        "name": "version",
                        "default": null,
                        "doc": "Version of the MLModel"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "type",
                        "default": null,
                        "doc": "Type of Algorithm or MLModel such as whether it is a Naive Bayes classifier, Convolutional Neural Network, etc"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "map",
                            "values": [
                              "string",
                              "int",
                              "float",
                              "double",
                              "boolean"
                            ]
                          }
                        ],
                        "name": "hyperParameters",
                        "default": null,
                        "doc": "Hyper Parameters of the MLModel\n\nNOTE: these are deprecated in favor of hyperParams"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": {
                              "type": "record",
                              "Aspect": {
                                "name": "mlHyperParam"
                              },
                              "name": "MLHyperParam",
                              "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                              "fields": [
                                {
                                  "type": "string",
                                  "name": "name",
                                  "doc": "Name of the MLHyperParam"
                                },
                                {
                                  "type": [
                                    "null",
                                    "string"
                                  ],
                                  "name": "description",
                                  "default": null,
                                  "doc": "Documentation of the MLHyperParam"
                                },
                                {
                                  "type": [
                                    "null",
                                    "string"
                                  ],
                                  "name": "value",
                                  "default": null,
                                  "doc": "The value of the MLHyperParam"
                                },
                                {
                                  "type": [
                                    "null",
                                    "long"
                                  ],
                                  "name": "createdAt",
                                  "default": null,
                                  "doc": "Date when the MLHyperParam was developed"
                                }
                              ],
                              "doc": "Properties associated with an ML Hyper Param"
                            }
                          }
                        ],
                        "name": "hyperParams",
                        "default": null,
                        "doc": "Hyperparameters of the MLModel"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": {
                              "type": "record",
                              "Aspect": {
                                "name": "mlMetric"
                              },
                              "name": "MLMetric",
                              "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                              "fields": [
                                {
                                  "type": "string",
                                  "name": "name",
                                  "doc": "Name of the mlMetric"
                                },
                                {
                                  "type": [
                                    "null",
                                    "string"
                                  ],
                                  "name": "description",
                                  "default": null,
                                  "doc": "Documentation of the mlMetric"
                                },
                                {
                                  "type": [
                                    "null",
                                    "string"
                                  ],
                                  "name": "value",
                                  "default": null,
                                  "doc": "The value of the mlMetric"
                                },
                                {
                                  "type": [
                                    "null",
                                    "long"
                                  ],
                                  "name": "createdAt",
                                  "default": null,
                                  "doc": "Date when the mlMetric was developed"
                                }
                              ],
                              "doc": "Properties associated with an ML Metric"
                            }
                          }
                        ],
                        "name": "trainingMetrics",
                        "default": null,
                        "doc": "Metrics of the MLModel used in training"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.ml.metadata.MLMetric"
                          }
                        ],
                        "name": "onlineMetrics",
                        "default": null,
                        "doc": "Metrics of the MLModel used in production"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "mlFeature"
                            ],
                            "isLineage": true,
                            "name": "Consumes"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "mlFeatures",
                        "default": null,
                        "doc": "List of features used for MLModel training",
                        "Urn": "MLFeatureUrn",
                        "urn_is_array": true
                      },
                      {
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "tags",
                        "default": [],
                        "doc": "Tags for the MLModel"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "mlModelDeployment"
                            ],
                            "name": "DeployedTo"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "deployments",
                        "default": null,
                        "doc": "Deployments for the MLModel",
                        "Urn": "Urn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "mlModelGroup"
                            ],
                            "isLineage": true,
                            "isUpstream": false,
                            "name": "MemberOf"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "groups",
                        "default": null,
                        "doc": "Groups the model belongs to",
                        "Urn": "Urn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "Properties associated with a ML Model"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "intendedUse"
                    },
                    "name": "IntendedUse",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "primaryUses",
                        "default": null,
                        "doc": "Primary Use cases for the MLModel."
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": {
                              "type": "enum",
                              "name": "IntendedUserType",
                              "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                              "symbols": [
                                "ENTERPRISE",
                                "HOBBY",
                                "ENTERTAINMENT"
                              ]
                            }
                          }
                        ],
                        "name": "primaryUsers",
                        "default": null,
                        "doc": "Primary Intended Users - For example, was the MLModel developed for entertainment purposes, for hobbyists, or enterprise solutions?"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "outOfScopeUses",
                        "default": null,
                        "doc": "Highlight technology that the MLModel might easily be confused with, or related contexts that users could try to apply the MLModel to."
                      }
                    ],
                    "doc": "Intended Use for the ML Model"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelFactorPrompts"
                    },
                    "name": "MLModelFactorPrompts",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": {
                              "type": "record",
                              "name": "MLModelFactors",
                              "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                              "fields": [
                                {
                                  "type": [
                                    "null",
                                    {
                                      "type": "array",
                                      "items": "string"
                                    }
                                  ],
                                  "name": "groups",
                                  "default": null,
                                  "doc": "Groups refers to distinct categories with similar characteristics that are present in the evaluation data instances.\nFor human-centric machine learning MLModels, groups are people who share one or multiple characteristics."
                                },
                                {
                                  "type": [
                                    "null",
                                    {
                                      "type": "array",
                                      "items": "string"
                                    }
                                  ],
                                  "name": "instrumentation",
                                  "default": null,
                                  "doc": "The performance of a MLModel can vary depending on what instruments were used to capture the input to the MLModel.\nFor example, a face detection model may perform differently depending on the camera's hardware and software,\nincluding lens, image stabilization, high dynamic range techniques, and background blurring for portrait mode."
                                },
                                {
                                  "type": [
                                    "null",
                                    {
                                      "type": "array",
                                      "items": "string"
                                    }
                                  ],
                                  "name": "environment",
                                  "default": null,
                                  "doc": "A further factor affecting MLModel performance is the environment in which it is deployed."
                                }
                              ],
                              "doc": "Factors affecting the performance of the MLModel."
                            }
                          }
                        ],
                        "name": "relevantFactors",
                        "default": null,
                        "doc": "What are foreseeable salient factors for which MLModel performance may vary, and how were these determined?"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "com.linkedin.pegasus2avro.ml.metadata.MLModelFactors"
                          }
                        ],
                        "name": "evaluationFactors",
                        "default": null,
                        "doc": "Which factors are being reported, and why were these chosen?"
                      }
                    ],
                    "doc": "Prompts which affect the performance of the MLModel"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelMetrics"
                    },
                    "name": "Metrics",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "performanceMeasures",
                        "default": null,
                        "doc": "Measures of MLModel performance"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "decisionThreshold",
                        "default": null,
                        "doc": "Decision Thresholds used (if any)?"
                      }
                    ],
                    "doc": "Metrics to be featured for the MLModel."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelEvaluationData"
                    },
                    "name": "EvaluationData",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "BaseData",
                            "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                            "fields": [
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.urn.DatasetUrn"
                                },
                                "type": "string",
                                "name": "dataset",
                                "doc": "What dataset were used in the MLModel?",
                                "Urn": "DatasetUrn"
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "motivation",
                                "default": null,
                                "doc": "Why was this dataset chosen?"
                              },
                              {
                                "type": [
                                  "null",
                                  {
                                    "type": "array",
                                    "items": "string"
                                  }
                                ],
                                "name": "preProcessing",
                                "default": null,
                                "doc": "How was the data preprocessed (e.g., tokenization of sentences, cropping of images, any filtering such as dropping images without faces)?"
                              }
                            ],
                            "doc": "BaseData record"
                          }
                        },
                        "name": "evaluationData",
                        "doc": "Details on the dataset(s) used for the quantitative analyses in the MLModel"
                      }
                    ],
                    "doc": "All referenced datasets would ideally point to any set of documents that provide visibility into the source and composition of the dataset."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelTrainingData"
                    },
                    "name": "TrainingData",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": "com.linkedin.pegasus2avro.ml.metadata.BaseData"
                        },
                        "name": "trainingData",
                        "doc": "Details on the dataset(s) used for training the MLModel"
                      }
                    ],
                    "doc": "Ideally, the MLModel card would contain as much information about the training data as the evaluation data. However, there might be cases where it is not feasible to provide this level of detailed information about the training data. For example, the data may be proprietary, or require a non-disclosure agreement. In these cases, we advocate for basic details about the distributions over groups in the data, as well as any other details that could inform stakeholders on the kinds of biases the model may have encoded."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelQuantitativeAnalyses"
                    },
                    "name": "QuantitativeAnalyses",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "unitaryResults",
                        "default": null,
                        "doc": "Link to a dashboard with results showing how the MLModel performed with respect to each factor"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "intersectionalResults",
                        "default": null,
                        "doc": "Link to a dashboard with results showing how the MLModel performed with respect to the intersection of evaluated factors?"
                      }
                    ],
                    "doc": "Quantitative analyses should be disaggregated, that is, broken down by the chosen factors. Quantitative analyses should provide the results of evaluating the MLModel according to the chosen metrics, providing confidence interval values when possible."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelEthicalConsiderations"
                    },
                    "name": "EthicalConsiderations",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "data",
                        "default": null,
                        "doc": "Does the MLModel use any sensitive data (e.g., protected classes)?"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "humanLife",
                        "default": null,
                        "doc": " Is the MLModel intended to inform decisions about matters central to human life or flourishing - e.g., health or safety? Or could it be used in such a way?"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "mitigations",
                        "default": null,
                        "doc": "What risk mitigation strategies were used during MLModel development?"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "risksAndHarms",
                        "default": null,
                        "doc": "What risks may be present in MLModel usage? Try to identify the potential recipients, likelihood, and magnitude of harms. If these cannot be determined, note that they were considered but remain unknown."
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "useCases",
                        "default": null,
                        "doc": "Are there any known MLModel use cases that are especially fraught? This may connect directly to the intended use section"
                      }
                    ],
                    "doc": "This section is intended to demonstrate the ethical considerations that went into MLModel development, surfacing ethical challenges and solutions to stakeholders."
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelCaveatsAndRecommendations"
                    },
                    "name": "CaveatsAndRecommendations",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": [
                          "null",
                          {
                            "type": "record",
                            "name": "CaveatDetails",
                            "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                            "fields": [
                              {
                                "type": [
                                  "null",
                                  "boolean"
                                ],
                                "name": "needsFurtherTesting",
                                "default": null,
                                "doc": "Did the results suggest any further testing?"
                              },
                              {
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "caveatDescription",
                                "default": null,
                                "doc": "Caveat Description\nFor ex: Given gender classes are binary (male/not male), which we include as male/female. Further work needed to evaluate across a spectrum of genders."
                              },
                              {
                                "type": [
                                  "null",
                                  {
                                    "type": "array",
                                    "items": "string"
                                  }
                                ],
                                "name": "groupsNotRepresented",
                                "default": null,
                                "doc": "Relevant groups that were not represented in the evaluation dataset?"
                              }
                            ],
                            "doc": "This section should list additional concerns that were not covered in the previous sections. For example, did the results suggest any further testing? Were there any relevant groups that were not represented in the evaluation dataset? Are there additional recommendations for model use?"
                          }
                        ],
                        "name": "caveats",
                        "default": null,
                        "doc": "This section should list additional concerns that were not covered in the previous sections. For example, did the results suggest any further testing? Were there any relevant groups that were not represented in the evaluation dataset?"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "recommendations",
                        "default": null,
                        "doc": "Recommendations on where this MLModel should be used."
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "idealDatasetCharacteristics",
                        "default": null,
                        "doc": "Ideal characteristics of an evaluation dataset for this MLModel"
                      }
                    ],
                    "doc": "This section should list additional concerns that were not covered in the previous sections. For example, did the results suggest any further testing? Were there any relevant groups that were not represented in the evaluation dataset? Are there additional recommendations for model use?"
                  },
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "sourceCode"
                    },
                    "name": "SourceCode",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "type": {
                          "type": "array",
                          "items": {
                            "type": "record",
                            "name": "SourceCodeUrl",
                            "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                            "fields": [
                              {
                                "type": {
                                  "type": "enum",
                                  "name": "SourceCodeUrlType",
                                  "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                                  "symbols": [
                                    "ML_MODEL_SOURCE_CODE",
                                    "TRAINING_PIPELINE_SOURCE_CODE",
                                    "EVALUATION_PIPELINE_SOURCE_CODE"
                                  ]
                                },
                                "name": "type",
                                "doc": "Source Code Url Types"
                              },
                              {
                                "java": {
                                  "class": "com.linkedin.pegasus2avro.common.url.Url",
                                  "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                                },
                                "type": "string",
                                "name": "sourceCodeUrl",
                                "doc": "Source Code Url"
                              }
                            ],
                            "doc": "Source Code Url Entity"
                          }
                        },
                        "name": "sourceCode",
                        "doc": "Source Code along with types"
                      }
                    ],
                    "doc": "Source Code"
                  },
                  "com.linkedin.pegasus2avro.common.Status",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "cost"
                    },
                    "name": "Cost",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "type": {
                          "type": "enum",
                          "symbolDocs": {
                            "ORG_COST_TYPE": "Org Cost Type to which the Cost of this entity should be attributed to"
                          },
                          "name": "CostType",
                          "namespace": "com.linkedin.pegasus2avro.common",
                          "symbols": [
                            "ORG_COST_TYPE"
                          ],
                          "doc": "Type of Cost Code"
                        },
                        "name": "costType"
                      },
                      {
                        "type": {
                          "type": "record",
                          "name": "CostCost",
                          "namespace": "com.linkedin.pegasus2avro.common",
                          "fields": [
                            {
                              "type": [
                                "null",
                                "double"
                              ],
                              "name": "costId",
                              "default": null
                            },
                            {
                              "type": [
                                "null",
                                "string"
                              ],
                              "name": "costCode",
                              "default": null
                            },
                            {
                              "type": {
                                "type": "enum",
                                "name": "CostCostDiscriminator",
                                "namespace": "com.linkedin.pegasus2avro.common",
                                "symbols": [
                                  "costId",
                                  "costCode"
                                ]
                              },
                              "name": "fieldDiscriminator",
                              "doc": "Contains the name of the field that has its value set."
                            }
                          ]
                        },
                        "name": "cost"
                      }
                    ]
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "deprecation"
                    },
                    "name": "Deprecation",
                    "namespace": "com.linkedin.pegasus2avro.common",
                    "fields": [
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "BOOLEAN",
                          "filterNameOverride": "Deprecated",
                          "weightsPerFieldValue": {
                            "true": 0.5
                          }
                        },
                        "type": "boolean",
                        "name": "deprecated",
                        "doc": "Whether the entity is deprecated."
                      },
                      {
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "decommissionTime",
                        "default": null,
                        "doc": "The time user plan to decommission this entity."
                      },
                      {
                        "type": "string",
                        "name": "note",
                        "doc": "Additional information about the entity deprecation plan, such as the wiki, doc, RB."
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "actor",
                        "doc": "The user URN which will be credited for modifying this deprecation content.",
                        "Urn": "Urn"
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "replacement",
                        "default": null,
                        "Urn": "Urn"
                      }
                    ],
                    "doc": "Deprecation status of an entity"
                  },
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the MLModel. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "MLModel Snapshot entity details."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "mlPrimaryKeyKey",
            "name": "mlPrimaryKey"
          },
          "name": "MLPrimaryKeySnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.Urn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "Urn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlPrimaryKeyKey"
                    },
                    "name": "MLPrimaryKeyKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "featureNamespace",
                        "doc": "Namespace for the primary key"
                      },
                      {
                        "Searchable": {
                          "boostScore": 8.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Name of the primary key"
                      }
                    ],
                    "doc": "Key for an MLPrimaryKey"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlPrimaryKeyProperties"
                    },
                    "name": "MLPrimaryKeyProperties",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the MLPrimaryKey"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "enum",
                            "symbolDocs": {
                              "AUDIO": "Audio Data",
                              "BINARY": "Binary data is discrete data that can be in only one of two categories - either yes or no, 1 or 0, off or on, etc",
                              "BYTE": "Bytes data are binary-encoded values that can represent complex objects.",
                              "CONTINUOUS": "Continuous data are made of uncountable values, often the result of a measurement such as height, weight, age etc.",
                              "COUNT": "Count data is discrete whole number data - no negative numbers here.\nCount data often has many small values, such as zero and one.",
                              "IMAGE": "Image Data",
                              "INTERVAL": "Interval data has equal spaces between the numbers and does not represent a temporal pattern.\nExamples include percentages, temperatures, and income.",
                              "MAP": "Mapping Data Type ex: dict, map",
                              "NOMINAL": "Nominal data is made of discrete values with no numerical relationship between the different categories - mean and median are meaningless.\nAnimal species is one example. For example, pig is not higher than bird and lower than fish.",
                              "ORDINAL": "Ordinal data are discrete integers that can be ranked or sorted.\nFor example, the distance between first and second may not be the same as the distance between second and third.",
                              "SEQUENCE": "Sequence Data Type ex: list, tuple, range",
                              "SET": "Set Data Type ex: set, frozenset",
                              "TEXT": "Text Data",
                              "TIME": "Time data is a cyclical, repeating continuous form of data.\nThe relevant time features can be any period- daily, weekly, monthly, annual, etc.",
                              "UNKNOWN": "Unknown data are data that we don't know the type for.",
                              "USELESS": "Useless data is unique, discrete data with no potential relationship with the outcome variable.\nA useless feature has high cardinality. An example would be bank account numbers that were generated randomly.",
                              "VIDEO": "Video Data"
                            },
                            "name": "MLFeatureDataType",
                            "namespace": "com.linkedin.pegasus2avro.common",
                            "symbols": [
                              "USELESS",
                              "NOMINAL",
                              "ORDINAL",
                              "BINARY",
                              "COUNT",
                              "TIME",
                              "INTERVAL",
                              "IMAGE",
                              "VIDEO",
                              "AUDIO",
                              "TEXT",
                              "MAP",
                              "SEQUENCE",
                              "SET",
                              "CONTINUOUS",
                              "BYTE",
                              "UNKNOWN"
                            ],
                            "doc": "MLFeature Data Type"
                          }
                        ],
                        "name": "dataType",
                        "default": null,
                        "doc": "Data Type of the MLPrimaryKey"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.VersionTag"
                        ],
                        "name": "version",
                        "default": null,
                        "doc": "Version of the MLPrimaryKey"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "DerivedFrom"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "sources",
                        "doc": "Source of the MLPrimaryKey",
                        "Urn": "Urn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "Properties associated with a MLPrimaryKey"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.Deprecation",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the MLPrimaryKey. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ]
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "mlFeatureKey",
            "name": "mlFeature"
          },
          "name": "MLFeatureSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.MLFeatureUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "MLFeatureUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlFeatureKey"
                    },
                    "name": "MLFeatureKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "featureNamespace",
                        "doc": "Namespace for the feature"
                      },
                      {
                        "Searchable": {
                          "boostScore": 8.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Name of the feature"
                      }
                    ],
                    "doc": "Key for an MLFeature"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlFeatureProperties"
                    },
                    "name": "MLFeatureProperties",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the MLFeature"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.MLFeatureDataType"
                        ],
                        "name": "dataType",
                        "default": null,
                        "doc": "Data Type of the MLFeature"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.VersionTag"
                        ],
                        "name": "version",
                        "default": null,
                        "doc": "Version of the MLFeature"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataset"
                            ],
                            "isLineage": true,
                            "name": "DerivedFrom"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "sources",
                        "default": null,
                        "doc": "Source of the MLFeature",
                        "Urn": "Urn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "Properties associated with a MLFeature"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.Deprecation",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the MLFeature. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ]
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "mlFeatureTableKey",
            "name": "mlFeatureTable"
          },
          "name": "MLFeatureTableSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.Urn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "Urn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlFeatureTableKey"
                    },
                    "name": "MLFeatureTableKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Relationship": {
                          "entityTypes": [
                            "dataPlatform"
                          ],
                          "name": "SourcePlatform"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "platform",
                        "doc": "Data platform urn associated with the feature table",
                        "Urn": "Urn",
                        "entityTypes": [
                          "dataPlatform"
                        ]
                      },
                      {
                        "Searchable": {
                          "boostScore": 8.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Name of the feature table"
                      }
                    ],
                    "doc": "Key for an MLFeatureTable"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlFeatureTableProperties"
                    },
                    "name": "MLFeatureTableProperties",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the MLFeatureTable"
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "mlFeature"
                            ],
                            "name": "Contains"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "features",
                            "fieldType": "URN"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "mlFeatures",
                        "default": null,
                        "doc": "List of features contained in the feature table",
                        "Urn": "Urn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "mlPrimaryKey"
                            ],
                            "name": "KeyedBy"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "primaryKeys",
                            "fieldType": "URN"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "mlPrimaryKeys",
                        "default": null,
                        "doc": "List of primary keys in the feature table (if multiple, assumed to act as a composite key)",
                        "Urn": "Urn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "Properties associated with a MLFeatureTable"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.InstitutionalMemory",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.Deprecation",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the MLFeatureTable. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ]
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "mlModelDeploymentKey",
            "name": "mlModelDeployment"
          },
          "name": "MLModelDeploymentSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.Urn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "Urn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelDeploymentKey"
                    },
                    "name": "MLModelDeploymentKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "platform",
                        "doc": "Standardized platform urn for the model Deployment",
                        "Urn": "Urn"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Name of the MLModelDeployment"
                      },
                      {
                        "Searchable": {
                          "addToFilters": true,
                          "fieldType": "TEXT_PARTIAL",
                          "filterNameOverride": "Environment",
                          "queryByDefault": false
                        },
                        "type": "com.linkedin.pegasus2avro.common.FabricType",
                        "name": "origin",
                        "doc": "Fabric type where model Deployment belongs to or where it was generated"
                      }
                    ],
                    "doc": "Key for an ML model deployment"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelDeploymentProperties"
                    },
                    "name": "MLModelDeploymentProperties",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the MLModelDeployment"
                      },
                      {
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "createdAt",
                        "default": null,
                        "doc": "Date when the MLModelDeployment was developed"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.VersionTag"
                        ],
                        "name": "version",
                        "default": null,
                        "doc": "Version of the MLModelDeployment"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "enum",
                            "symbolDocs": {
                              "CREATING": "Deployments being created.",
                              "DELETING": "Deployments being deleted.",
                              "FAILED": "Deployments with an error state.",
                              "IN_SERVICE": "Deployments that are active.",
                              "OUT_OF_SERVICE": "Deployments out of service.",
                              "ROLLING_BACK": "Deployments being reverted to a previous version.",
                              "UNKNOWN": "Deployments with unknown/unmappable state.",
                              "UPDATING": "Deployments being updated."
                            },
                            "name": "DeploymentStatus",
                            "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                            "symbols": [
                              "OUT_OF_SERVICE",
                              "CREATING",
                              "UPDATING",
                              "ROLLING_BACK",
                              "IN_SERVICE",
                              "DELETING",
                              "FAILED",
                              "UNKNOWN"
                            ],
                            "doc": "Model endpoint statuses"
                          }
                        ],
                        "name": "status",
                        "default": null,
                        "doc": "Status of the deployment"
                      }
                    ],
                    "doc": "Properties associated with an ML Model Deployment"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.Deprecation",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the MLModelDeployment. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ]
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "mlModelGroupKey",
            "name": "mlModelGroup"
          },
          "name": "MLModelGroupSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.Urn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "Urn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelGroupKey"
                    },
                    "name": "MLModelGroupKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "platform",
                        "doc": "Standardized platform urn for the model group",
                        "Urn": "Urn"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Name of the MLModelGroup"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL",
                          "queryByDefault": false
                        },
                        "type": "com.linkedin.pegasus2avro.common.FabricType",
                        "name": "origin",
                        "doc": "Fabric type where model group belongs to or where it was generated"
                      }
                    ],
                    "doc": "Key for an ML model group"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "mlModelGroupProperties"
                    },
                    "name": "MLModelGroupProperties",
                    "namespace": "com.linkedin.pegasus2avro.ml.metadata",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataJob",
                              "dataProcessInstance"
                            ],
                            "isLineage": true,
                            "name": "TrainedBy"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "trainingJobs",
                        "default": null,
                        "doc": "List of jobs or process instances (if any) used to train the model or group. Visible in Lineage. Note that ML Models can also be specified as the output of a specific Data Process Instances (runs) via the DataProcessInstanceOutputs aspect."
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "dataJob",
                              "dataProcessInstance"
                            ],
                            "isLineage": true,
                            "isUpstream": false,
                            "name": "UsedBy"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "downstreamJobs",
                        "default": null,
                        "doc": "List of jobs or process instances (if any) that use the model or group."
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "externalUrl",
                        "default": null,
                        "doc": "URL where the reference exist"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM",
                          "queryByDefault": true
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "name",
                        "default": null,
                        "doc": "Display name of the MLModelGroup"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT",
                          "hasValuesFieldName": "hasDescription"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the MLModelGroup"
                      },
                      {
                        "deprecated": true,
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "createdAt",
                        "default": null,
                        "doc": "Date when the MLModelGroup was developed"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "created",
                        "default": null,
                        "doc": "Time and Actor who created the MLModelGroup"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.TimeStamp"
                        ],
                        "name": "lastModified",
                        "default": null,
                        "doc": "Date when the MLModelGroup was last modified"
                      },
                      {
                        "type": [
                          "null",
                          "com.linkedin.pegasus2avro.common.VersionTag"
                        ],
                        "name": "version",
                        "default": null,
                        "doc": "Version of the MLModelGroup"
                      }
                    ],
                    "doc": "Properties associated with an ML Model Group"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.Deprecation",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  "com.linkedin.pegasus2avro.common.GlobalTags",
                  "com.linkedin.pegasus2avro.common.DataPlatformInstance",
                  "com.linkedin.pegasus2avro.common.BrowsePathsV2"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the MLModelGroup. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ]
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "tagKey",
            "name": "tag"
          },
          "name": "TagSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.TagUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "TagUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "tagKey"
                    },
                    "name": "TagKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldName": "id",
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "The tag name, which serves as a unique id"
                      }
                    ],
                    "doc": "Key for a Tag"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "tagProperties"
                    },
                    "name": "TagProperties",
                    "namespace": "com.linkedin.pegasus2avro.tag",
                    "fields": [
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "Display name of the tag"
                      },
                      {
                        "Searchable": {},
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "description",
                        "default": null,
                        "doc": "Documentation of the tag"
                      },
                      {
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "colorHex",
                        "default": null,
                        "doc": "The color associated with the Tag in Hex. For example #FFFFFF."
                      }
                    ],
                    "doc": "Properties associated with a Tag"
                  },
                  "com.linkedin.pegasus2avro.common.Status"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the dataset. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific dataset entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "glossaryTermKey",
            "name": "glossaryTerm"
          },
          "name": "GlossaryTermSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.GlossaryTermUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "GlossaryTermUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "glossaryTermKey"
                    },
                    "name": "GlossaryTermKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "enableAutocomplete": true,
                          "fieldName": "id",
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name",
                        "doc": "The term name, which serves as a unique id"
                      }
                    ],
                    "doc": "Key for a GlossaryTerm"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "glossaryTermInfo"
                    },
                    "name": "GlossaryTermInfo",
                    "namespace": "com.linkedin.pegasus2avro.glossary",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "id",
                        "default": null,
                        "doc": "Optional id for the term"
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "name",
                        "default": null,
                        "doc": "Display name of the term"
                      },
                      {
                        "Searchable": {},
                        "type": "string",
                        "name": "definition",
                        "doc": "Definition of business term."
                      },
                      {
                        "Relationship": {
                          "entityTypes": [
                            "glossaryNode"
                          ],
                          "name": "IsPartOf"
                        },
                        "Searchable": {
                          "fieldName": "parentNode",
                          "fieldType": "URN",
                          "hasValuesFieldName": "hasParentNode"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.GlossaryNodeUrn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "parentNode",
                        "default": null,
                        "doc": "Parent node of the glossary term",
                        "Urn": "GlossaryNodeUrn",
                        "entityTypes": [
                          "glossaryNode"
                        ]
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "type": "string",
                        "name": "termSource",
                        "doc": "Source of the Business Term (INTERNAL or EXTERNAL) with default value as INTERNAL"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "sourceRef",
                        "default": null,
                        "doc": "External Reference to the business-term"
                      },
                      {
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.url.Url",
                          "coercerClass": "com.linkedin.pegasus2avro.common.url.UrlCoercer"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "sourceUrl",
                        "default": null,
                        "doc": "The abstracted URL such as https://spec.edmcouncil.org/fibo/ontology/FBC/FinancialInstruments/FinancialInstruments/CashInstrument."
                      },
                      {
                        "deprecated": true,
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "rawSchema",
                        "default": null,
                        "doc": "Schema definition of the glossary term"
                      }
                    ],
                    "doc": "Properties associated with a GlossaryTerm"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status",
                  "com.linkedin.pegasus2avro.common.BrowsePaths",
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "glossaryRelatedTerms"
                    },
                    "name": "GlossaryRelatedTerms",
                    "namespace": "com.linkedin.pegasus2avro.glossary",
                    "fields": [
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "glossaryTerm"
                            ],
                            "name": "IsA"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "isRelatedTerms",
                            "fieldType": "URN",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "isRelatedTerms",
                        "default": null,
                        "doc": "The relationship Is A with glossary term",
                        "Urn": "GlossaryTermUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "glossaryTerm"
                            ],
                            "name": "HasA"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "hasRelatedTerms",
                            "fieldType": "URN",
                            "queryByDefault": false
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "hasRelatedTerms",
                        "default": null,
                        "doc": "The relationship Has A with glossary term",
                        "Urn": "GlossaryTermUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "glossaryTerm"
                            ],
                            "name": "HasValue"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "values",
                            "fieldType": "URN"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "values",
                        "default": null,
                        "doc": "The relationship Has Value with glossary term.\nThese are fixed value a term has. For example a ColorEnum where RED, GREEN and YELLOW are fixed values.",
                        "Urn": "GlossaryTermUrn",
                        "urn_is_array": true
                      },
                      {
                        "Relationship": {
                          "/*": {
                            "entityTypes": [
                              "glossaryTerm"
                            ],
                            "name": "IsRelatedTo"
                          }
                        },
                        "Searchable": {
                          "/*": {
                            "fieldName": "relatedTerms",
                            "fieldType": "URN"
                          }
                        },
                        "type": [
                          "null",
                          {
                            "type": "array",
                            "items": "string"
                          }
                        ],
                        "name": "relatedTerms",
                        "default": null,
                        "doc": "The relationship isRelatedTo with glossary term",
                        "Urn": "GlossaryTermUrn",
                        "urn_is_array": true
                      }
                    ],
                    "doc": "Has A / Is A lineage information about a glossary Term reporting the lineage"
                  }
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the GlossaryTerm. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific GlossaryTerm entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "glossaryNodeKey",
            "name": "glossaryNode"
          },
          "name": "GlossaryNodeSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.GlossaryNodeUrn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "GlossaryNodeUrn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "glossaryNodeKey"
                    },
                    "name": "GlossaryNodeKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "enableAutocomplete": true,
                          "fieldType": "WORD_GRAM"
                        },
                        "type": "string",
                        "name": "name"
                      }
                    ],
                    "doc": "Key for a GlossaryNode"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "glossaryNodeInfo"
                    },
                    "name": "GlossaryNodeInfo",
                    "namespace": "com.linkedin.pegasus2avro.glossary",
                    "fields": [
                      {
                        "Searchable": {
                          "/*": {
                            "fieldType": "TEXT",
                            "queryByDefault": true
                          }
                        },
                        "type": {
                          "type": "map",
                          "values": "string"
                        },
                        "name": "customProperties",
                        "default": {},
                        "doc": "Custom property bag."
                      },
                      {
                        "Searchable": {},
                        "type": "string",
                        "name": "definition",
                        "doc": "Definition of business node"
                      },
                      {
                        "Relationship": {
                          "entityTypes": [
                            "glossaryNode"
                          ],
                          "name": "IsPartOf"
                        },
                        "Searchable": {
                          "fieldName": "parentNode",
                          "fieldType": "URN",
                          "hasValuesFieldName": "hasParentNode"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.GlossaryNodeUrn"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "parentNode",
                        "default": null,
                        "doc": "Parent node of the glossary term",
                        "Urn": "GlossaryNodeUrn",
                        "entityTypes": [
                          "glossaryNode"
                        ]
                      },
                      {
                        "Searchable": {
                          "boostScore": 10.0,
                          "enableAutocomplete": true,
                          "fieldName": "displayName",
                          "fieldNameAliases": [
                            "_entityName"
                          ],
                          "fieldType": "WORD_GRAM"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "name",
                        "default": null,
                        "doc": "Display name of the node"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": [
                          "null",
                          "string"
                        ],
                        "name": "id",
                        "default": null,
                        "doc": "Optional id for the GlossaryNode"
                      }
                    ],
                    "doc": "Properties associated with a GlossaryNode"
                  },
                  "com.linkedin.pegasus2avro.common.Ownership",
                  "com.linkedin.pegasus2avro.common.Status"
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the GlossaryNode. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific GlossaryNode entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "dataHubPolicyKey",
            "name": "dataHubPolicy"
          },
          "name": "DataHubPolicySnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.Urn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "Urn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataHubPolicyKey"
                    },
                    "name": "DataHubPolicyKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "type": "string",
                        "name": "id",
                        "doc": "A unique id for the DataHub access policy record. Generated on the server side at policy creation time."
                      }
                    ],
                    "doc": "Key for a DataHub Policy"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataHubPolicyInfo"
                    },
                    "name": "DataHubPolicyInfo",
                    "namespace": "com.linkedin.pegasus2avro.policy",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "TEXT_PARTIAL"
                        },
                        "type": "string",
                        "name": "displayName",
                        "doc": "Display name of the Policy"
                      },
                      {
                        "Searchable": {
                          "fieldType": "TEXT"
                        },
                        "type": "string",
                        "name": "description",
                        "doc": "Description of the Policy"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "type": "string",
                        "name": "type",
                        "doc": "The type of policy"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "type": "string",
                        "name": "state",
                        "doc": "The state of policy, ACTIVE or INACTIVE"
                      },
                      {
                        "type": [
                          "null",
                          {
                            "type": "record",
                            "name": "DataHubResourceFilter",
                            "namespace": "com.linkedin.pegasus2avro.policy",
                            "fields": [
                              {
                                "deprecated": true,
                                "type": [
                                  "null",
                                  "string"
                                ],
                                "name": "type",
                                "default": null,
                                "doc": "The type of resource that the policy applies to. This will most often be a data asset entity name, for\nexample 'dataset'. It is not strictly required because in the future we will want to support filtering a resource\nby domain, as well."
                              },
                              {
                                "deprecated": true,
                                "type": [
                                  "null",
                                  {
                                    "type": "array",
                                    "items": "string"
                                  }
                                ],
                                "name": "resources",
                                "default": null,
                                "doc": "A specific set of resources to apply the policy to, e.g. asset urns"
                              },
                              {
                                "deprecated": true,
                                "type": "boolean",
                                "name": "allResources",
                                "default": false,
                                "doc": "Whether the policy should be applied to all assets matching the filter."
                              },
                              {
                                "type": [
                                  "null",
                                  {
                                    "type": "record",
                                    "name": "PolicyMatchFilter",
                                    "namespace": "com.linkedin.pegasus2avro.policy",
                                    "fields": [
                                      {
                                        "type": {
                                          "type": "array",
                                          "items": {
                                            "type": "record",
                                            "name": "PolicyMatchCriterion",
                                            "namespace": "com.linkedin.pegasus2avro.policy",
                                            "fields": [
                                              {
                                                "type": "string",
                                                "name": "field",
                                                "doc": "The name of the field that the criterion refers to"
                                              },
                                              {
                                                "type": {
                                                  "type": "array",
                                                  "items": "string"
                                                },
                                                "name": "values",
                                                "doc": "Values. Matches criterion if any one of the values matches condition (OR-relationship)"
                                              },
                                              {
                                                "type": {
                                                  "type": "enum",
                                                  "symbolDocs": {
                                                    "EQUALS": "Whether the field matches the value",
                                                    "STARTS_WITH": "Whether the field value starts with the value"
                                                  },
                                                  "name": "PolicyMatchCondition",
                                                  "namespace": "com.linkedin.pegasus2avro.policy",
                                                  "symbols": [
                                                    "EQUALS",
                                                    "STARTS_WITH"
                                                  ],
                                                  "doc": "The matching condition in a filter criterion"
                                                },
                                                "name": "condition",
                                                "default": "EQUALS",
                                                "doc": "The condition for the criterion"
                                              }
                                            ],
                                            "doc": "A criterion for matching a field with given value"
                                          }
                                        },
                                        "name": "criteria",
                                        "doc": "A list of criteria to apply conjunctively (so all criteria must pass)"
                                      }
                                    ],
                                    "doc": "The filter for specifying the resource or actor to apply privileges to"
                                  }
                                ],
                                "name": "filter",
                                "default": null,
                                "doc": "Filter to apply privileges to"
                              }
                            ],
                            "doc": "Information used to filter DataHub resource."
                          }
                        ],
                        "name": "resources",
                        "default": null,
                        "doc": "The resource that the policy applies to. Not required for some 'Platform' privileges."
                      },
                      {
                        "Searchable": {
                          "/*": {
                            "addToFilters": true,
                            "fieldType": "KEYWORD"
                          }
                        },
                        "type": {
                          "type": "array",
                          "items": "string"
                        },
                        "name": "privileges",
                        "doc": "The privileges that the policy grants."
                      },
                      {
                        "type": {
                          "type": "record",
                          "name": "DataHubActorFilter",
                          "namespace": "com.linkedin.pegasus2avro.policy",
                          "fields": [
                            {
                              "Searchable": {
                                "/*": {
                                  "fieldType": "URN"
                                }
                              },
                              "type": [
                                "null",
                                {
                                  "type": "array",
                                  "items": "string"
                                }
                              ],
                              "name": "users",
                              "default": null,
                              "doc": "A specific set of users to apply the policy to (disjunctive)",
                              "Urn": "Urn",
                              "urn_is_array": true
                            },
                            {
                              "Searchable": {
                                "/*": {
                                  "fieldType": "URN"
                                }
                              },
                              "type": [
                                "null",
                                {
                                  "type": "array",
                                  "items": "string"
                                }
                              ],
                              "name": "groups",
                              "default": null,
                              "doc": "A specific set of groups to apply the policy to (disjunctive)",
                              "Urn": "Urn",
                              "urn_is_array": true
                            },
                            {
                              "type": "boolean",
                              "name": "resourceOwners",
                              "default": false,
                              "doc": "Whether the filter should return true for owners of a particular resource.\nOnly applies to policies of type 'Metadata', which have a resource associated with them."
                            },
                            {
                              "type": [
                                "null",
                                {
                                  "type": "array",
                                  "items": "string"
                                }
                              ],
                              "name": "resourceOwnersTypes",
                              "default": null,
                              "doc": "Define type of ownership for the policy",
                              "Urn": "Urn",
                              "urn_is_array": true
                            },
                            {
                              "Searchable": {
                                "fieldType": "BOOLEAN"
                              },
                              "type": "boolean",
                              "name": "allUsers",
                              "default": false,
                              "doc": "Whether the filter should apply to all users."
                            },
                            {
                              "Searchable": {
                                "fieldType": "BOOLEAN"
                              },
                              "type": "boolean",
                              "name": "allGroups",
                              "default": false,
                              "doc": "Whether the filter should apply to all groups."
                            },
                            {
                              "Relationship": {
                                "/*": {
                                  "entityTypes": [
                                    "dataHubRole"
                                  ],
                                  "name": "IsAssociatedWithRole"
                                }
                              },
                              "Searchable": {
                                "/*": {
                                  "fieldType": "URN"
                                }
                              },
                              "type": [
                                "null",
                                {
                                  "type": "array",
                                  "items": "string"
                                }
                              ],
                              "name": "roles",
                              "default": null,
                              "doc": "A specific set of roles to apply the policy to (disjunctive).",
                              "Urn": "Urn",
                              "urn_is_array": true
                            }
                          ],
                          "doc": "Information used to filter DataHub actors."
                        },
                        "name": "actors",
                        "doc": "The actors that the policy applies to."
                      },
                      {
                        "Searchable": {
                          "fieldType": "BOOLEAN"
                        },
                        "type": "boolean",
                        "name": "editable",
                        "default": true,
                        "doc": "Whether the policy should be editable via the UI"
                      },
                      {
                        "Searchable": {
                          "fieldType": "DATETIME"
                        },
                        "type": [
                          "null",
                          "long"
                        ],
                        "name": "lastUpdatedTimestamp",
                        "default": null,
                        "doc": "Timestamp when the policy was last updated"
                      }
                    ],
                    "doc": "Information about a DataHub (UI) access policy."
                  }
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the DataHub access policy."
            }
          ],
          "doc": "A metadata snapshot for DataHub Access Policy data."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "schemaFieldKey",
            "name": "schemaField"
          },
          "name": "SchemaFieldSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.Urn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "Urn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "schemaFieldKey"
                    },
                    "name": "SchemaFieldKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "Searchable": {
                          "fieldType": "URN"
                        },
                        "java": {
                          "class": "com.linkedin.pegasus2avro.common.urn.Urn"
                        },
                        "type": "string",
                        "name": "parent",
                        "doc": "Parent associated with the schema field",
                        "Urn": "Urn"
                      },
                      {
                        "Searchable": {
                          "fieldType": "KEYWORD"
                        },
                        "type": "string",
                        "name": "fieldPath",
                        "doc": "fieldPath identifying the schema field"
                      }
                    ],
                    "doc": "Key for a SchemaField"
                  }
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the dataset. Depending on the use case, this can either be all, or a selection, of supported aspects."
            }
          ],
          "doc": "A metadata snapshot for a specific schema field entity."
        },
        {
          "type": "record",
          "Entity": {
            "keyAspect": "dataHubRetentionKey",
            "name": "dataHubRetention"
          },
          "name": "DataHubRetentionSnapshot",
          "namespace": "com.linkedin.pegasus2avro.metadata.snapshot",
          "fields": [
            {
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.Urn"
              },
              "type": "string",
              "name": "urn",
              "doc": "URN for the entity the metadata snapshot is associated with.",
              "Urn": "Urn"
            },
            {
              "type": {
                "type": "array",
                "items": [
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataHubRetentionKey"
                    },
                    "name": "DataHubRetentionKey",
                    "namespace": "com.linkedin.pegasus2avro.metadata.key",
                    "fields": [
                      {
                        "type": "string",
                        "name": "entityName",
                        "doc": "Entity name to apply retention to. * (or empty) for applying defaults."
                      },
                      {
                        "type": "string",
                        "name": "aspectName",
                        "doc": "Aspect name to apply retention to. * (or empty) for applying defaults."
                      }
                    ],
                    "doc": "Key for a DataHub Retention"
                  },
                  {
                    "type": "record",
                    "Aspect": {
                      "name": "dataHubRetentionConfig"
                    },
                    "name": "DataHubRetentionConfig",
                    "namespace": "com.linkedin.pegasus2avro.retention",
                    "fields": [
                      {
                        "type": {
                          "type": "record",
                          "name": "Retention",
                          "namespace": "com.linkedin.pegasus2avro.retention",
                          "fields": [
                            {
                              "type": [
                                "null",
                                {
                                  "type": "record",
                                  "name": "VersionBasedRetention",
                                  "namespace": "com.linkedin.pegasus2avro.retention",
                                  "fields": [
                                    {
                                      "type": "int",
                                      "name": "maxVersions"
                                    }
                                  ],
                                  "doc": "Keep max N latest records"
                                }
                              ],
                              "name": "version",
                              "default": null
                            },
                            {
                              "type": [
                                "null",
                                {
                                  "type": "record",
                                  "name": "TimeBasedRetention",
                                  "namespace": "com.linkedin.pegasus2avro.retention",
                                  "fields": [
                                    {
                                      "type": "int",
                                      "name": "maxAgeInSeconds"
                                    }
                                  ],
                                  "doc": "Keep records that are less than X seconds old"
                                }
                              ],
                              "name": "time",
                              "default": null
                            }
                          ],
                          "doc": "Base class that encapsulates different retention policies.\nOnly one of the fields should be set"
                        },
                        "name": "retention"
                      }
                    ]
                  }
                ]
              },
              "name": "aspects",
              "doc": "The list of metadata aspects associated with the DataHub access policy."
            }
          ],
          "doc": "A metadata snapshot for DataHub Access Policy data."
        }
      ],
      "name": "proposedSnapshot",
      "doc": "Snapshot of the proposed metadata change. Include only the aspects affected by the change in the snapshot."
    },
    {
      "type": [
        "null"
      ],
      "name": "proposedDelta",
      "default": null,
      "doc": "Delta of the proposed metadata partial update."
    },
    {
      "type": [
        "null",
        {
          "type": "record",
          "name": "SystemMetadata",
          "namespace": "com.linkedin.pegasus2avro.mxe",
          "fields": [
            {
              "type": [
                "long",
                "null"
              ],
              "name": "lastObserved",
              "default": 0,
              "doc": "The timestamp the metadata was observed at"
            },
            {
              "type": [
                "string",
                "null"
              ],
              "name": "runId",
              "default": "no-run-id-provided",
              "doc": "The original run id that produced the metadata. Populated in case of batch-ingestion."
            },
            {
              "type": [
                "string",
                "null"
              ],
              "name": "lastRunId",
              "default": "no-run-id-provided",
              "doc": "The last run id that produced the metadata. Populated in case of batch-ingestion."
            },
            {
              "type": [
                "null",
                "string"
              ],
              "name": "pipelineName",
              "default": null,
              "doc": "The ingestion pipeline id that produced the metadata. Populated in case of batch ingestion."
            },
            {
              "type": [
                "null",
                "string"
              ],
              "name": "registryName",
              "default": null,
              "doc": "The model registry name that was used to process this event"
            },
            {
              "type": [
                "null",
                "string"
              ],
              "name": "registryVersion",
              "default": null,
              "doc": "The model registry version that was used to process this event"
            },
            {
              "type": [
                "null",
                {
                  "type": "map",
                  "values": "string"
                }
              ],
              "name": "properties",
              "default": null,
              "doc": "Additional properties"
            },
            {
              "type": [
                "null",
                "string"
              ],
              "name": "version",
              "default": null,
              "doc": "Aspect version\n   Initial implementation will use the aspect version's number, however stored as\n   a string in the case where a different aspect versioning scheme is later adopted."
            }
          ],
          "doc": "Metadata associated with each metadata change that is processed by the system"
        }
      ],
      "name": "systemMetadata",
      "default": null,
      "doc": "Metadata around how the snapshot was ingested"
    }
  ],
  "doc": "Kafka event for proposing a metadata change for an entity. A corresponding MetadataAuditEvent is emitted when the change is accepted and committed, otherwise a FailedMetadataChangeEvent will be emitted instead."
}